@@ -1,4 +1,3 @@
-/* vim: set sw=8 ts=8: -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*
  * ms-formula-write.c: export GnmExpr to xls
  *
@@ -80,13 +79,14 @@ cb_excel_write_prep_expr (GnmExpr const *expr, GnmExprWalk *data)
 	switch (GNM_EXPR_GET_OPER (expr)) {
 	case GNM_EXPR_OP_FUNCALL: {
 		GnmFunc *func = expr->func.func;
+		GnmFuncFlags flags = gnm_func_get_flags (func);
 		ExcelFunc *ef = g_hash_table_lookup (ewb->function_map, func);
 		if (ef != NULL)
 			break;
 
 		ef = g_new (ExcelFunc, 1);
-		ef->efunc = (func->flags & (GNM_FUNC_IS_PLACEHOLDER |
-					    GNM_FUNC_IS_WORKBOOK_LOCAL))
+		ef->efunc = (flags & (GNM_FUNC_IS_PLACEHOLDER |
+				      GNM_FUNC_IS_WORKBOOK_LOCAL))
 			? NULL
 			: g_hash_table_lookup (excel_func_by_name,
 					       func->name);
@@ -98,7 +98,7 @@ cb_excel_write_prep_expr (GnmExpr const *expr, GnmExprWalk *data)
 		} else if (ef->efunc) {
 			ef->macro_name = NULL;
 			ef->idx = ef->efunc->idx;
-		} else if (func->flags & GNM_FUNC_IS_WORKBOOK_LOCAL) {
+		} else if (flags & GNM_FUNC_IS_WORKBOOK_LOCAL) {
 			ef->macro_name = g_strdup (func->name);
 			ef->idx = -1;
 		} else {
@@ -502,24 +502,25 @@ excel_formula_write_AREA (PolishData *pd, GnmCellRef const *a, GnmCellRef const
 }
 
 static char *
-guess_arg_types (const GnmFunc *func)
+guess_arg_types (GnmFunc *func)
 {
-	char *res, *p;
+	char *res;
+	int i, min, max;
 
-	if (func->fn_type != GNM_FUNC_TYPE_ARGS)
+	if (!gnm_func_is_fixargs (func))
 		return NULL;
 
-	res = g_strdup (func->fn.args.arg_types);
+	gnm_func_count_args (func, &min, &max);
 
-	for (p = res; *p; p++) {
-		switch (*p) {
-		case 'r':
-		case 'A':
-			*p = 'A';
-			break;
-		default:
-			*p = 'V';
-		}
+	res = g_new (char, max + 1);
+	res[max] = 0;
+
+	for (i = 0; i < max; i++) {
+		char t = gnm_func_get_arg_type (func, i);
+		if (t == 'r' || t == 'A')
+			res[i] = 'A';
+		else
+			res[i] = 'V';
 	}
 
 #if FORMULA_DEBUG > 1
