@@ -1,4 +1,3 @@
-/* vim: set sw=8: -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /* Interface Gnumeric to Databases
  * Copyright (C) 1998,1999 Michael Lausch
  * Copyright (C) 2000-2002 Rodrigo Moya
@@ -27,13 +26,13 @@
 #include <sql-parser/gda-sql-parser.h>
 #include <string.h>
 
-#include "func.h"
-#include "expr.h"
-#include "value.h"
-#include "workbook.h"
-#include "sheet.h"
-#include "gnm-i18n.h"
-#include "gui-util.h"
+#include <func.h>
+#include <expr.h>
+#include <value.h>
+#include <workbook.h>
+#include <sheet.h>
+#include <gnm-i18n.h>
+#include <gui-util.h>
 #include <goffice/goffice.h>
 #include <gnm-plugin.h>
 #include <dead-kittens.h>
