@@ -1,4 +1,3 @@
-/* vim: set sw=8: -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*
  * html.c
  *
@@ -22,29 +21,29 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ * along with this program; if not, see <https://www.gnu.org/licenses/>.
  */
 
 #include <gnumeric-config.h>
 #include <gnumeric.h>
 #include <goffice/goffice.h>
-#include "workbook-view.h"
-#include "workbook.h"
-#include "sheet-style.h"
-#include "style.h"
-#include "style-color.h"
+#include <workbook-view.h>
+#include <workbook.h>
+#include <sheet-style.h>
+#include <style.h>
+#include <style-color.h>
 #include "html.h"
-#include "cell.h"
-#include "sheet.h"
-#include "sheet-merge.h"
-#include "value.h"
+#include <cell.h>
+#include <sheet.h>
+#include <sheet-merge.h>
+#include <value.h>
 #include "font.h"
-#include "cellspan.h"
-#include "style-border.h"
+#include <cellspan.h>
+#include <style-border.h>
 #include <rendered-value.h>
-#include "style.h"
-#include "hlink.h"
+#include <style.h>
+#include <hlink.h>
+#include <gutils.h>
 
 #include <gsf/gsf-output.h>
 #include <string.h>
@@ -663,10 +662,9 @@ write_sheet (GsfOutput *output, Sheet *sheet,
 
 	switch (version) {
 	case HTML40:
-		gsf_output_puts (output, "<p><table cellspacing=\"0\" cellpadding=\"3\">\n");
-		break;
+	case HTML40F:
 	case XHTML:
-		gsf_output_puts (output, "<p /><table cellspacing=\"0\" cellpadding=\"3\">\n");
+		gsf_output_puts (output, "<p></p><table cellspacing=\"0\" cellpadding=\"3\">\n");
 		break;
 	default:
 		gsf_output_puts (output, "<p><table border=\"1\">\n");
@@ -696,9 +694,10 @@ static void
 html_file_save (GOFileSaver const *fs, GOIOContext *io_context,
 		WorkbookView const *wb_view, GsfOutput *output, html_version_t version)
 {
-	GSList *sheets, *ptr;
 	Workbook *wb = wb_view_get_workbook (wb_view);
 	GOFileSaveScope save_scope;
+	GPtrArray *sel;
+	unsigned ui;
 
 	g_return_if_fail (fs != NULL);
 	g_return_if_fail (wb != NULL);
@@ -777,12 +776,15 @@ html_file_save (GOFileSaver const *fs, GOIOContext *io_context,
 		break;
 	}
 
-	sheets = workbook_sheets (wb);
 	save_scope = go_file_saver_get_save_scope (fs);
-	for (ptr = sheets ; ptr != NULL ; ptr = ptr->next) {
-		write_sheet (output, (Sheet *) ptr->data, version, save_scope);
+
+	sel = gnm_file_saver_get_sheets (fs, wb_view, TRUE);
+	for (ui = 0; ui < sel->len; ui++) {
+		Sheet *sheet = g_ptr_array_index (sel, ui);
+		write_sheet (output, sheet, version, save_scope);
 	}
-	g_slist_free (sheets);
+	g_ptr_array_unref (sel);
+
 	if (version == HTML32 || version == HTML40 || version == XHTML)
 		gsf_output_puts (output, "</body>\n</html>\n");
 }
