@@ -1283,7 +1283,7 @@ file_saver_sheet_get_extent (Sheet *sheet)
  * @filename:         where we'll write.
  *
  * This writes the top sheet of a Gnumeric workbook to a LaTeX2e longtable. We
- * check for merges here, then call the function latex2e_write_multicolum_cell()
+ * check for merges here, then call the function latex2e_write_multicolumn_cell()
  * to render the format and contents of the cell.
  */
 void
@@ -1321,7 +1321,7 @@ latex_file_save (GOFileSaver const *fs, G_GNUC_UNUSED GOIOContext *io_context,
 "\\setlength\\gnumericTableWidthComplete{\\gnumericTableWidth+%\n"
 "         \\tabcolsep*\\gumericNumCols*2+\\arrayrulewidth*\\gumericNumCols}\n"
 "\\ifthenelse{\\lengthtest{\\gnumericTableWidthComplete > \\linewidth}}%\n"
-"         {\\def\\gnumericScale{\\ratio{\\linewidth-%\n"
+"         {\\def\\gnumericScale{1*\\ratio{\\linewidth-%\n"
 "                        \\tabcolsep*\\gumericNumCols*2-%\n"
 "                        \\arrayrulewidth*\\gumericNumCols}%\n"
 "{\\gnumericTableWidth}}}%\n"
@@ -1466,7 +1466,7 @@ latex_file_save (GOFileSaver const *fs, G_GNUC_UNUSED GOIOContext *io_context,
 	/* We need to check for horizontal borders at the bottom  of  the last  row */
 	clines = g_new0 (GnmStyleBorderType, total_range.end.col - total_range.start.col + 1);
 	needs_hline = FALSE;
-	/* In case that we are at the very bottom of the sheet we can not */
+	/* In case that we are at the very bottom of the sheet we cannot */
 	/* check on the next line! */
 	if (row < colrow_max (FALSE, current_sheet)) {
 		length = num_cols;
