@@ -45,7 +45,7 @@ typedef GObjectClass GnmPerlPluginLoaderClass;
 static GnmValue*
 call_perl_function_args (GnmFuncEvalInfo *ei, GnmValue const * const *args)
 {
-	GnmFunc const *fndef;
+	GnmFunc *fndef;
 	gint min_n_args, max_n_args, n_args;
 	gint i;
 	gchar *perl_func;
@@ -53,7 +53,7 @@ call_perl_function_args (GnmFuncEvalInfo *ei, GnmValue const * const *args)
 	dSP;
 
 	fndef = gnm_expr_get_func_def ((GnmExpr *)(ei->func_call));
-	perl_func = g_strconcat ("func_", fndef->name, NULL);
+	perl_func = g_strconcat ("func_", gnm_func_get_name (fndef, FALSE), NULL);
 
 	gnm_func_count_args (fndef, &min_n_args, &max_n_args);
 	for (n_args = min_n_args; n_args < max_n_args && args[n_args] != NULL; n_args++);
@@ -199,11 +199,10 @@ make_gnm_help (const char *name, int count, SV **SP)
 	return help;
 }
 
-static gboolean
-gplp_func_desc_load (GOPluginService *service,
-		     char const *name,
-		     GnmFuncDescriptor *res)
+static void
+gplp_func_load_stub (GOPluginService *service, GnmFunc *func)
 {
+	char const *name = gnm_func_get_name (func, FALSE);
 	char *args[] = { NULL };
 	gchar *help_perl_func = g_strconcat ("help_", name, NULL);
 	gchar *desc_perl_func = g_strconcat ("desc_", name, NULL);
@@ -254,18 +253,9 @@ gplp_func_desc_load (GOPluginService *service,
 	g_free (help_perl_func);
 	g_free (desc_perl_func);
 
-	res->name = g_strdup(name);
-	res->arg_spec = arg_spec;
-
-	res->help = help;
-	res->fn_args = NULL;
-	res->fn_args = &call_perl_function_args;
-	res->fn_nodes = NULL;
-	res->linker = NULL;
-	res->impl_status = GNM_FUNC_IMPL_STATUS_UNIQUE_TO_GNUMERIC;
-	res->test_status = GNM_FUNC_TEST_STATUS_UNKNOWN;
-
-	return TRUE;
+	gnm_func_set_fixargs (func, call_perl_function_args, arg_spec);
+	gnm_func_set_help (func, help, -1);
+	gnm_func_set_impl_status (func, GNM_FUNC_IMPL_STATUS_UNIQUE_TO_GNUMERIC);
 }
 
 static void
@@ -328,7 +318,7 @@ gplp_load_service_function_group (GOPluginLoader *loader,
 	GO_INIT_RET_ERROR_INFO (ret_error);
 
 	cbs = go_plugin_service_get_cbs (service);
-	cbs->func_desc_load = &gplp_func_desc_load;
+	cbs->load_stub = &gplp_func_load_stub;
 }
 
 static gboolean
