@@ -1,4 +1,3 @@
-/* vim: set sw=8: */
 
 /*
  * psiconv-read.c : Routines to read Psion 5 series Sheet files
@@ -28,23 +27,23 @@
 #include <glib/gi18n-lib.h>
 #include <gnumeric.h>
 #include "psiconv-plugin.h"
-#include "application.h"
-#include "expr.h"
-#include "value.h"
-#include "sheet.h"
-#include "number-match.h"
-#include "cell.h"
-#include "parse-util.h"
-#include "sheet-style.h"
-#include "style.h"
-#include "style-border.h"
-#include "style-color.h"
-#include "selection.h"
-#include "position.h"
-#include "ranges.h"
+#include <application.h>
+#include <expr.h>
+#include <value.h>
+#include <sheet.h>
+#include <number-match.h>
+#include <cell.h>
+#include <parse-util.h>
+#include <sheet-style.h>
+#include <style.h>
+#include <style-border.h>
+#include <style-color.h>
+#include <selection.h>
+#include <position.h>
+#include <ranges.h>
 #include <goffice/goffice.h>
-#include "workbook-view.h"
-#include "workbook.h"
+#include <workbook-view.h>
+#include <workbook.h>
 
 #include <string.h>
 #include <stdlib.h>
