@@ -7,14 +7,11 @@
 #include "gnm-py-interpreter.h"
 #include <gnumeric-fwd.h>
 
-void     py_initgnumeric (GnmPyInterpreter *interpreter);
+PyObject *py_initgnumeric (void);
+void      py_gnumeric_add_plugin (PyObject *module, GnmPyInterpreter *interpreter);
 
 GnmValue *call_python_function	 (PyObject *python_fn,
 				  GnmEvalPos const *eval_pos,
 				  gint n_args, GnmValue const * const *args);
 gchar    *py_exc_to_string	 (void);
-PyObject *py_new_Sheet_object	 (Sheet *sheet);
-PyObject *py_new_Workbook_object (Workbook *wb);
-PyObject *py_new_Gui_object	 (WBCGtk *wbcg);
-
-#endif /* PLUGIN_PY_GNUMERIC_H */
+#endif /* PLUGIN_PY_GNUMERIC_H */
\ No newline at end of file
