@@ -1,4 +1,3 @@
-/* vim: set sw=8: -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*
  * auto-format.c: Suggest formats for expressions.
  *
@@ -11,17 +10,17 @@
  */
 
 #include <gnumeric-config.h>
-#include "gnumeric.h"
-#include "auto-format.h"
+#include <gnumeric.h>
+#include <auto-format.h>
 
-#include "compilation.h"
-#include "func.h"
-#include "cell.h"
-#include "value.h"
-#include "expr.h"
-#include "expr-impl.h"
-#include "sheet.h"
-#include "workbook.h"
+#include <compilation.h>
+#include <func.h>
+#include <cell.h>
+#include <value.h>
+#include <expr.h>
+#include <expr-impl.h>
+#include <sheet.h>
+#include <workbook.h>
 #include <goffice/goffice.h>
 
 /* ------------------------------------------------------------------------- */
@@ -135,8 +134,8 @@ do_af_suggest (GnmExpr const *expr, GnmEvalPos const *epos, GOFormat const **exp
 		return do_af_suggest (expr->binary.value_a, epos, explicit);
 
 	case GNM_EXPR_OP_FUNCALL: {
-		GnmFuncFlags typ =
-			(expr->func.func->flags & GNM_FUNC_AUTO_MASK);
+		GnmFuncFlags typ = (gnm_func_get_flags (expr->func.func) &
+				    GNM_FUNC_AUTO_MASK);
 
 		switch (typ) {
 		case GNM_FUNC_AUTO_FIRST:
