@@ -2,7 +2,7 @@
  * dependent.c:  Manage calculation dependencies between objects
  *
  * Copyright (C) 2000-2006 Jody Goldberg (jody@gnome.org)
- * Copyright (C) 2006-2013 Morten Welinder (terra@gnome.org)
+ * Copyright (C) 2006-2020 Morten Welinder (terra@gnome.org)
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -44,6 +44,13 @@ static gboolean gnm_cell_eval_content (GnmCell *cell);
 static void dependent_changed (GnmDependent *dep);
 static void dependent_clear_dynamic_deps (GnmDependent *dep);
 
+typedef enum {
+	DEP_LINK_NON_SCALAR = 1,
+
+	DEP_LINK_LINK = 0x8000,
+	DEP_LINK_UNLINK = 0
+} DepLinkFlags;
+
 /* ------------------------------------------------------------------------- */
 
 /*
@@ -76,10 +83,60 @@ static GOMemChunk *cset_pool;
 /* ------------------------------------------------------------------------- */
 /* Maps between row numbers and bucket numbers.  */
 
-#define BUCKET_SIZE	1024
-#define BUCKET_OF_ROW(row) ((row) / BUCKET_SIZE)
-#define BUCKET_START_ROW(b) ((b) * BUCKET_SIZE)
-#define BUCKET_END_ROW(b) ((b) * BUCKET_SIZE + (BUCKET_SIZE - 1))
+// The bucket size grows with row number:
+//
+// * The first 8 buckets have size 128
+// * The next 8 buckets have size 256
+// * The next 8 buckets have size 512
+// * Etc.
+//
+// A 64k row sheet will have 49 buckets; a 1M row sheet will have 81.
+
+#define BUCKET_BASE_SIZE_BITS 7
+#define BUCKET_BASE_SIZE (1u << BUCKET_BASE_SIZE_BITS)
+#define BUCKET_REP_BITS 3
+#define BUCKET_REP (1u << BUCKET_REP_BITS)
+
+static inline int
+bucket_of_row (unsigned row)
+{
+	unsigned sb, sb0, i;
+	unsigned sbs = BUCKET_REP * BUCKET_BASE_SIZE;
+
+#ifdef __GNUC__
+	// Super block
+	sb = __builtin_clz (1u) - __builtin_clz (1u + row / sbs);
+
+	// Super block start
+	sb0 = (sbs << sb) - sbs;
+#else
+	sb0 = 0;
+	for (sb = 0; TRUE; sb++) {
+		unsigned next_sb0 = ((2u << sb) - 1) * sbs;
+		if (row < next_sb0)
+			break;
+		sb0 = next_sb0;
+	}
+#endif
+	// Index (0-7) within super block
+	i = (row - sb0) >> (BUCKET_BASE_SIZE_BITS + sb);
+
+	return (int)(sb * BUCKET_REP + i);
+}
+
+static inline int
+bucket_start_row (unsigned b)
+{
+	unsigned sb = b / BUCKET_REP;
+	unsigned s = ((BUCKET_REP + (b % BUCKET_REP)) << sb) - BUCKET_REP;
+	return (int)(s << BUCKET_BASE_SIZE_BITS);
+}
+
+static inline int
+bucket_end_row (int b)
+{
+	return bucket_start_row (b + 1) - 1;
+}
 
 /* ------------------------------------------------------------------------- */
 
@@ -282,6 +339,15 @@ static const GnmDependentClass managed_dep_class = {
 	managed_dep_debug_name,
 };
 
+static GnmCellPos *managed_dep_pos (GnmDependent const *dep);
+static const GnmDependentClass managed_pos_dep_class = {
+	dummy_dep_eval,
+	NULL,
+	NULL,
+	managed_dep_pos,
+	managed_dep_debug_name,
+};
+
 static void style_dep_eval (GnmDependent *dep);
 static GSList *style_dep_changed (GnmDependent *dep);
 static GnmCellPos *style_dep_pos (GnmDependent const *dep);
@@ -313,6 +379,7 @@ dependent_types_init (void)
 	g_ptr_array_add	(dep_classes, (gpointer)&dynamic_dep_class);
 	g_ptr_array_add	(dep_classes, (gpointer)&name_dep_class);
 	g_ptr_array_add	(dep_classes, (gpointer)&managed_dep_class);
+	g_ptr_array_add	(dep_classes, (gpointer)&managed_pos_dep_class);
 	g_ptr_array_add	(dep_classes, (gpointer)&style_dep_class);
 
 #if USE_POOLS
@@ -804,7 +871,7 @@ micro_hash_is_empty (MicroHash const *hash_table)
 /*************************************************************************/
 
 #define micro_hash_foreach_dep(dc, dep, code) do {			\
-        guint i_ = dc.num_elements;					\
+	guint i_ = dc.num_elements;					\
 	if (i_ <= MICRO_HASH_FEW) {					\
 		const gpointer *e_ = (i_ == 1) ? &dc.u.one : dc.u.few;	\
 		while (i_-- > 0) {					\
@@ -944,9 +1011,9 @@ unlink_single_dep (GnmDependent *dep, GnmCellPos const *pos, GnmCellRef const *a
 
 static inline GnmDependentFlags
 link_unlink_single_dep (GnmDependent *dep, GnmCellPos const *pos,
-			GnmCellRef const *a, gboolean qlink)
+			GnmCellRef const *a, DepLinkFlags flags)
 {
-	return qlink
+	return (flags & DEP_LINK_LINK)
 		? link_single_dep (dep, pos, a)
 		: unlink_single_dep (dep, pos, a);
 }
@@ -954,11 +1021,14 @@ link_unlink_single_dep (GnmDependent *dep, GnmCellPos const *pos,
 
 static void
 link_range_dep (GnmDepContainer *deps, GnmDependent *dep,
-		DependencyRange const *r)
+		GnmRange const *r)
 {
-	int i = BUCKET_OF_ROW (r->range.start.row);
-	int end = BUCKET_OF_ROW (r->range.end.row);
-	DependencyRange r2 = *r;
+	int i = bucket_of_row (r->start.row);
+	int end = bucket_of_row (r->end.row);
+	DependencyRange dr;
+	int next_start;
+
+	dr.range = *r;
 
 	/*
 	 * It is possible to see ranges bigger than the sheet when
@@ -966,19 +1036,25 @@ link_range_dep (GnmDepContainer *deps, GnmDependent *dep,
 	 */
 	end = MIN (end, deps->buckets - 1);
 
+	if (i > end)
+		return;
+
+	next_start = bucket_start_row (i);
 	for ( ; i <= end; i++) {
 		DependencyRange *result;
+		int start = next_start;
+		next_start = bucket_start_row (i + 1);
 
 		/* Restrict range to bucket.  */
-		r2.range.start.row = MAX (r->range.start.row, BUCKET_START_ROW (i));
-		r2.range.end.row = MIN (r->range.end.row, BUCKET_END_ROW (i));
+		dr.range.start.row = MAX (r->start.row, start);
+		dr.range.end.row = MIN (r->end.row, next_start - 1);
 
 		if (deps->range_hash[i] == NULL)
 			deps->range_hash[i] = g_hash_table_new (
 				(GHashFunc)  deprange_hash,
 				(GEqualFunc) deprange_equal);
 		else {
-			result = g_hash_table_lookup (deps->range_hash[i], &r2);
+			result = g_hash_table_lookup (deps->range_hash[i], &dr);
 			if (result) {
 				/* Inserts if it is not already there */
 				micro_hash_insert (&result->deps, dep);
@@ -988,7 +1064,7 @@ link_range_dep (GnmDepContainer *deps, GnmDependent *dep,
 
 		/* Create a new DependencyRange structure */
 		result = go_mem_chunk_alloc (deps->range_pool);
-		*result = r2;
+		*result = dr;
 		micro_hash_init (&result->deps, dep);
 		g_hash_table_insert (deps->range_hash[i], result, result);
 	}
@@ -996,25 +1072,33 @@ link_range_dep (GnmDepContainer *deps, GnmDependent *dep,
 
 static void
 unlink_range_dep (GnmDepContainer *deps, GnmDependent *dep,
-		  DependencyRange const *r)
+		  GnmRange const *r)
 {
-	int i = BUCKET_OF_ROW (r->range.start.row);
-	int end = BUCKET_OF_ROW (r->range.end.row);
-	DependencyRange r2 = *r;
+	int i = bucket_of_row (r->start.row);
+	int end = bucket_of_row (r->end.row);
+	DependencyRange dr;
+	int next_start;
 
 	if (!deps)
 		return;
+	dr.range = *r;
 
 	end = MIN (end, deps->buckets - 1);
 
+	if (i > end)
+		return;
+
+	next_start = bucket_start_row (i);
 	for ( ; i <= end; i++) {
 		DependencyRange *result;
+		int start = next_start;
+		next_start = bucket_start_row (i + 1);
 
 		/* Restrict range to bucket.  */
-		r2.range.start.row = MAX (r->range.start.row, BUCKET_START_ROW (i));
-		r2.range.end.row = MIN (r->range.end.row, BUCKET_END_ROW (i));
+		dr.range.start.row = MAX (r->start.row, start);
+		dr.range.end.row = MIN (r->end.row, next_start - 1);
 
-		result = g_hash_table_lookup (deps->range_hash[i], &r2);
+		result = g_hash_table_lookup (deps->range_hash[i], &dr);
 		if (result) {
 			micro_hash_remove (&result->deps, dep);
 			if (micro_hash_is_empty (&result->deps)) {
@@ -1028,9 +1112,9 @@ unlink_range_dep (GnmDepContainer *deps, GnmDependent *dep,
 
 static inline void
 link_unlink_range_dep (GnmDepContainer *deps, GnmDependent *dep,
-		       DependencyRange const *r, gboolean qlink)
+		       GnmRange const *r, DepLinkFlags flags)
 {
-	if (qlink)
+	if (flags & DEP_LINK_LINK)
 		link_range_dep (deps, dep, r);
 	else
 		unlink_range_dep (deps, dep, r);
@@ -1039,14 +1123,14 @@ link_unlink_range_dep (GnmDepContainer *deps, GnmDependent *dep,
 static GnmDependentFlags
 link_unlink_cellrange_dep (GnmDependent *dep, GnmCellPos const *pos,
 			   GnmCellRef const *a, GnmCellRef const *b,
-			   gboolean qlink)
+			   DepLinkFlags flags)
 {
-	DependencyRange range;
+	GnmRange range;
 	GnmDependentFlags flag = DEPENDENT_NO_FLAG;
 
-	gnm_cellpos_init_cellref (&range.range.start, a, pos, dep->sheet);
-	gnm_cellpos_init_cellref (&range.range.end, b, pos, dep->sheet);
-	range_normalize (&range.range);
+	gnm_cellpos_init_cellref (&range.start, a, pos, dep->sheet);
+	gnm_cellpos_init_cellref (&range.end, b, pos, dep->sheet);
+	range_normalize (&range);
 
 	if (a->sheet != NULL) {
 		if (a->sheet != dep->sheet)
@@ -1065,73 +1149,151 @@ link_unlink_cellrange_dep (GnmDependent *dep, GnmCellPos const *pos,
 				Sheet *sheet = g_ptr_array_index (wb->sheets, i);
 				i++;
 				link_unlink_range_dep (sheet->deps, dep, &range,
-						       qlink);
+						       flags);
 			}
 			flag |= DEPENDENT_HAS_3D;
 		} else
 			link_unlink_range_dep (a->sheet->deps, dep, &range,
-					       qlink);
+					       flags);
 	} else
-		link_unlink_range_dep (dep->sheet->deps, dep, &range, qlink);
+		link_unlink_range_dep (dep->sheet->deps, dep, &range, flags);
 
 	return flag;
 }
 
 static GnmDependentFlags
-link_unlink_expr_dep (GnmEvalPos *ep, GnmExpr const *tree, gboolean qlink)
+link_unlink_expr_dep (GnmEvalPos *ep, GnmExpr const *tree, DepLinkFlags flags);
+
+static GnmDependentFlags
+link_unlink_constant (GnmEvalPos *ep, GnmValue const *v, DepLinkFlags flags)
+{
+	GnmRange r;
+	Sheet *start_sheet, *end_sheet;
+	int col, row;
+	gboolean found = FALSE;
+	GnmCellRef cr;
+
+	if (!VALUE_IS_CELLRANGE (v))
+		return DEPENDENT_NO_FLAG;
+
+	if (!dependent_is_cell (ep->dep))
+		goto everything; // Must figure out semantics first
+
+	if (flags & DEP_LINK_NON_SCALAR)
+		goto everything;
+
+	if (eval_pos_is_array_context (ep))
+		goto everything; // Potential implicit iteration -- bail
+
+	// Inspiration from value_intersection:
+
+	gnm_rangeref_normalize (&v->v_range.cell, ep, &start_sheet, &end_sheet, &r);
+	if (!(start_sheet == end_sheet || end_sheet == NULL))
+		return DEPENDENT_NO_FLAG; // An error
+
+	col = ep->eval.col;
+	row = ep->eval.row;
+
+	if (range_is_singleton (&r)) {
+		col = r.start.col;
+		row = r.start.row;
+		found = TRUE;
+	} else if (r.start.row == r.end.row &&
+		   r.start.col <= col && col <= r.end.col) {
+		row = r.start.row;
+		found = TRUE;
+	} else if (r.start.col == r.end.col &&
+		   r.start.row <= row && row <= r.end.row) {
+		col = r.start.col;
+		found = TRUE;
+	}
+	if (!found)
+		goto everything;
+
+	cr.col_relative = cr.row_relative = FALSE;
+	cr.sheet = ep->dep->sheet;
+	cr.col = col;
+	cr.row = row;
+
+	return link_unlink_single_dep (ep->dep, dependent_pos (ep->dep),
+				       &cr, flags);
+
+everything:
+	return link_unlink_cellrange_dep
+		(ep->dep, dependent_pos (ep->dep),
+		 &v->v_range.cell.a,
+		 &v->v_range.cell.b,
+		 flags);
+}
+
+static GnmDependentFlags
+link_unlink_funcall (GnmEvalPos *ep, GnmExprFunction const *call, DepLinkFlags flags)
+{
+	int i;
+	GnmFuncEvalInfo fei;
+	GnmDependentFlags flag;
+	DepLinkFlags pass = (flags & (DEP_LINK_LINK | DEP_LINK_UNLINK));
+
+	gnm_func_load_if_stub (call->func);
+	fei.pos = ep;
+	fei.func_call = call;
+	flag = gnm_func_link_dep (call->func, &fei, (flags & DEP_LINK_LINK) != 0);
+	if (flag & DEPENDENT_IGNORE_ARGS)
+		return (flag & ~DEPENDENT_IGNORE_ARGS);
+
+	for (i = 0; i < call->argc; i++) {
+		char t = gnm_func_get_arg_type (call->func, i);
+		DepLinkFlags extra =
+			(t == 'A' || t == 'r' || t == '?')
+			? DEP_LINK_NON_SCALAR
+			: 0;
+
+		if (0)
+			g_printerr ("%s, arg %d: %c\n",
+				    gnm_func_get_name (call->func, FALSE),
+				    i, t);
+		flag |= link_unlink_expr_dep (ep, call->argv[i], pass | extra);
+	}
+	return flag;
+}
+
+
+static GnmDependentFlags
+link_unlink_expr_dep (GnmEvalPos *ep, GnmExpr const *tree, DepLinkFlags flags)
 {
 	g_return_val_if_fail (tree != NULL, DEPENDENT_NO_FLAG);
 
 	switch (GNM_EXPR_GET_OPER (tree)) {
-	case GNM_EXPR_OP_RANGE_CTOR:  /* See #562363 */
+	case GNM_EXPR_OP_RANGE_CTOR:
 	case GNM_EXPR_OP_INTERSECT:
+		return (link_unlink_expr_dep (ep, tree->binary.value_a, flags) |
+			link_unlink_expr_dep (ep, tree->binary.value_b, flags));
 	case GNM_EXPR_OP_ANY_BINARY:
-		return link_unlink_expr_dep (ep, tree->binary.value_a, qlink) |
-		       link_unlink_expr_dep (ep, tree->binary.value_b, qlink);
+		// See comments in function_iterate_argument_values
+		if (!eval_pos_is_array_context (ep))
+			flags &= ~DEP_LINK_NON_SCALAR;
+		return (link_unlink_expr_dep (ep, tree->binary.value_a, flags) |
+			link_unlink_expr_dep (ep, tree->binary.value_b, flags));
 	case GNM_EXPR_OP_ANY_UNARY:
-		return link_unlink_expr_dep (ep, tree->unary.value, qlink);
+		if (!eval_pos_is_array_context (ep))
+			flags &= ~DEP_LINK_NON_SCALAR;
+		return link_unlink_expr_dep (ep, tree->unary.value, flags);
 	case GNM_EXPR_OP_CELLREF:
-		return link_unlink_single_dep (ep->dep, dependent_pos (ep->dep), &tree->cellref.ref, qlink);
+		return link_unlink_single_dep (ep->dep, dependent_pos (ep->dep), &tree->cellref.ref, flags);
 
 	case GNM_EXPR_OP_CONSTANT:
-		/* TODO: pass in eval flags so that we can use implicit
-		 * intersection
-		 */
-		if (VALUE_IS_CELLRANGE (tree->constant.value))
-			return link_unlink_cellrange_dep
-				(ep->dep, dependent_pos (ep->dep),
-				 &tree->constant.value->v_range.cell.a,
-				 &tree->constant.value->v_range.cell.b,
-				 qlink);
-		return DEPENDENT_NO_FLAG;
+		return link_unlink_constant (ep, tree->constant.value, flags);
 
-	/*
-	 * FIXME: needs to be taught implicit intersection +
-	 * more cunning handling of argument type matching.
-	 */
-	case GNM_EXPR_OP_FUNCALL: {
-		int i;
-		GnmFuncEvalInfo fei;
-		GnmDependentFlags flag;
-
-		gnm_func_load_if_stub (tree->func.func);
-		fei.pos = ep;
-		fei.func_call = &tree->func;
-		flag = gnm_func_link_dep (tree->func.func, &fei, qlink);
-
-		if (!(flag & DEPENDENT_IGNORE_ARGS))
-			for (i = 0; i < tree->func.argc; i++)
-				flag |= link_unlink_expr_dep (ep, tree->func.argv[i], qlink);
-		return flag;
-	}
+	case GNM_EXPR_OP_FUNCALL:
+		return link_unlink_funcall (ep, &tree->func, flags);
 
 	case GNM_EXPR_OP_NAME:
-		if (qlink)
+		if (flags & DEP_LINK_LINK)
 			expr_name_add_dep (tree->name.name, ep->dep);
 		else
 			expr_name_remove_dep (tree->name.name, ep->dep);
 		if (expr_name_is_active (tree->name.name))
-			return link_unlink_expr_dep (ep, tree->name.name->texpr->expr, qlink) | DEPENDENT_USES_NAME;
+			return link_unlink_expr_dep (ep, tree->name.name->texpr->expr, flags) | DEPENDENT_USES_NAME;
 		return DEPENDENT_USES_NAME;
 
 	case GNM_EXPR_OP_ARRAY_ELEM: {
@@ -1147,7 +1309,7 @@ link_unlink_expr_dep (GnmEvalPos *ep, GnmExpr const *tree, gboolean qlink)
 		a.col   = pos->col - tree->array_elem.x;
 		a.row   = pos->row - tree->array_elem.y;
 
-		return link_unlink_single_dep (ep->dep, pos, &a, qlink);
+		return link_unlink_single_dep (ep->dep, pos, &a, flags);
 	}
 
 	case GNM_EXPR_OP_ARRAY_CORNER: {
@@ -1157,15 +1319,20 @@ link_unlink_expr_dep (GnmEvalPos *ep, GnmExpr const *tree, gboolean qlink)
 		GnmEvalPos pos = *ep;
 		pos.array_texpr = cell->base.texpr;
 		/* Corner cell depends on the contents of the expr */
-		return link_unlink_expr_dep (&pos, tree->array_corner.expr, qlink);
+		return link_unlink_expr_dep (&pos, tree->array_corner.expr,
+					     flags | DEP_LINK_NON_SCALAR);
 	}
 
 	case GNM_EXPR_OP_SET: {
 		int i;
 		GnmDependentFlags res = DEPENDENT_NO_FLAG;
 
-		for (i = 0; i < tree->set.argc; i++)
-			res |= link_unlink_expr_dep (ep, tree->set.argv[i], qlink);
+		// gnm_expr_eval ignores arguments unless non-scalar
+		if (flags & DEP_LINK_NON_SCALAR) {
+			for (i = 0; i < tree->set.argc; i++)
+				res |= link_unlink_expr_dep (ep, tree->set.argv[i], flags);
+		}
+
 		return res;
 	}
 #ifndef DEBUG_SWITCH_ENUM
@@ -1306,19 +1473,36 @@ cell_dep_debug_name (GnmDependent const *dep, GString *target)
  * the dependency system so it follows row/column insert/delete nicely.
  *
  * The expression being managed is typically a cell range, but can be any
- * expression.  Everything is interpreted relative to A1 in the sheet.
+ * expression.  There are two versions: only with a position and one without.
+ * In the no-position version, everything is interpreted relative to A1 in the
+ * sheet.
  */
 
 void
-dependent_managed_init (GnmDependent *dep, Sheet *sheet)
+dependent_managed_init (GnmDepManaged *dep, Sheet *sheet)
 {
 	memset (dep, 0, sizeof (*dep));
-	dep->flags = DEPENDENT_MANAGED;
-	dep->sheet = sheet;
+	dep->base.flags = DEPENDENT_MANAGED;
+	dep->base.sheet = sheet;
 }
 
 void
-dependent_managed_set_expr (GnmDependent *dep, GnmExprTop const *texpr)
+dependent_managed_pos_init (GnmDepManaged *dep, Sheet *sheet, GnmCellPos const *pos)
+{
+	dependent_managed_init (dep, sheet);
+	dep->base.flags = DEPENDENT_MANAGED_POS;
+	dep->pos = *pos;
+}
+
+GnmExprTop const *
+dependent_managed_get_expr (GnmDepManaged const *dep)
+{
+	g_return_val_if_fail (dep != NULL, NULL);
+	return dep->base.texpr;
+}
+
+void
+dependent_managed_set_expr (GnmDepManaged *dep, GnmExprTop const *texpr)
 {
 	g_return_if_fail (dep != NULL);
 #if 0
@@ -1326,13 +1510,13 @@ dependent_managed_set_expr (GnmDependent *dep, GnmExprTop const *texpr)
 	g_return_if_fail (dependent_type (dep) == DEPENDENT_MANAGED);
 #endif
 
-	dependent_set_expr (dep, texpr);
-	if (texpr && dep->sheet)
-		dependent_link (dep);
+	dependent_set_expr (&dep->base, texpr);
+	if (texpr && dep->base.sheet)
+		dependent_link (&dep->base);
 }
 
 void
-dependent_managed_set_sheet (GnmDependent *dep, Sheet *sheet)
+dependent_managed_set_sheet (GnmDepManaged *dep, Sheet *sheet)
 {
 	GnmExprTop const *texpr;
 
@@ -1342,14 +1526,14 @@ dependent_managed_set_sheet (GnmDependent *dep, Sheet *sheet)
 	g_return_if_fail (dependent_type (dep) == DEPENDENT_MANAGED);
 #endif
 
-	if (dep->sheet == sheet)
+	if (dep->base.sheet == sheet)
 		return;
 
-	texpr = dep->texpr;
+	texpr = dep->base.texpr;
 	if (texpr) gnm_expr_top_ref (texpr);
-	dependent_set_expr (dep, NULL);
+	dependent_set_expr (&dep->base, NULL);
 	/* We're now unlinked from everything. */
-	dep->sheet = sheet;
+	dep->base.sheet = sheet;
 	dependent_managed_set_expr (dep, texpr);
 	if (texpr) gnm_expr_top_unref (texpr);
 }
@@ -1360,6 +1544,12 @@ managed_dep_debug_name (GnmDependent const *dep, GString *target)
 	g_string_append_printf (target, "Managed%p", (void *)dep);
 }
 
+static GnmCellPos *
+managed_dep_pos (GnmDependent const *dep)
+{
+	return &((GnmDepManaged*)dep)->pos;
+}
+
 /*****************************************************************************/
 
 static gboolean
@@ -1492,7 +1682,7 @@ dependent_add_dynamic_dep (GnmDependent *dep, GnmRangeRef const *rr)
 		flags = link_single_dep (&dyn->base, pos, &rr->a);
 		dyn->singles = g_slist_prepend (dyn->singles, gnm_rangeref_dup (rr));
 	} else {
-		flags = link_unlink_cellrange_dep (&dyn->base, pos, &rr->a, &rr->b, TRUE);
+		flags = link_unlink_cellrange_dep (&dyn->base, pos, &rr->a, &rr->b, DEP_LINK_LINK);
 		dyn->ranges = g_slist_prepend (dyn->ranges, gnm_rangeref_dup (rr));
 	}
 	if (flags & DEPENDENT_HAS_3D)
@@ -1537,7 +1727,7 @@ dependent_link (GnmDependent *dep)
 	sheet->deps->tail = dep;
 	dep->flags |= DEPENDENT_IS_LINKED |
 		link_unlink_expr_dep (eval_pos_init_dep (&ep, dep),
-				      dep->texpr->expr, TRUE);
+				      dep->texpr->expr, DEP_LINK_LINK);
 
 	if (dep->flags & DEPENDENT_HAS_3D)
 		workbook_link_3d_dep (dep);
@@ -1562,7 +1752,7 @@ dependent_unlink (GnmDependent *dep)
 	g_return_if_fail (IS_SHEET (dep->sheet));
 
 	link_unlink_expr_dep (eval_pos_init_dep (&ep, dep),
-			      dep->texpr->expr, FALSE);
+			      dep->texpr->expr, DEP_LINK_UNLINK);
 	contain = dep->sheet->deps;
 	if (contain != NULL) {
 		if (contain->head == dep)
@@ -1609,7 +1799,7 @@ gnm_cell_eval_content (GnmCell *cell)
 		char *str = gnm_expr_top_as_string
 			(cell->base.texpr,
 			 parse_pos_init_cell (&pp, cell),
-			 NULL);
+			 sheet_get_conventions (cell->base.sheet));
 		g_printerr ("{\nEvaluating %s!%s: %s;\n",
 			    cell->base.sheet->name_quoted, cell_name (cell),
 			    str);
@@ -1797,47 +1987,28 @@ cell_queue_recalc (GnmCell *cell)
 	}
 }
 
-typedef struct {
-	int col, row;
-	GnmDepFunc func;
-	gpointer user;
-} search_rangedeps_closure_t;
-
-static void
-cb_search_rangedeps (gpointer key, G_GNUC_UNUSED gpointer value,
-		     gpointer closure)
-{
-	search_rangedeps_closure_t const *c = closure;
-	DependencyRange const *deprange = key;
-	GnmRange const *range = &(deprange->range);
-
-#if 0
-	/* When things get slow this is a good test to enable */
-	static int counter = 0;
-	if ((++counter % 100000) == 0)
-		g_printerr ("%d\n", counter / 100000);
-#endif
-
-	if (range_contains (range, c->col, c->row)) {
-		GnmDepFunc func = c->func;
-		micro_hash_foreach_dep (deprange->deps, dep,
-			(func) (dep, c->user););
-	}
-}
-
 static void
 cell_foreach_range_dep (GnmCell const *cell, GnmDepFunc func, gpointer user)
 {
-	search_rangedeps_closure_t closure;
+	Sheet *sheet = cell->base.sheet;
 	GHashTable *bucket =
-		cell->base.sheet->deps->range_hash[BUCKET_OF_ROW (cell->pos.row)];
+		sheet->deps->range_hash[bucket_of_row (cell->pos.row)];
+	GHashTableIter hiter;
+	gpointer key;
 
-	if (bucket != NULL) {
-		closure.col = cell->pos.col;
-		closure.row = cell->pos.row;
-		closure.func = func;
-		closure.user = user;
-		g_hash_table_foreach (bucket, &cb_search_rangedeps, &closure);
+	if (!bucket)
+		return;
+
+	g_hash_table_iter_init (&hiter, bucket);
+	while (g_hash_table_iter_next (&hiter, &key, NULL)) {
+		DependencyRange const *deprange = key;
+		GnmRange const *range = &(deprange->range);
+
+		if (!range_contains (range, cell->pos.col, cell->pos.row))
+			continue;
+
+		micro_hash_foreach_dep (deprange->deps, dep,
+					func (dep, user););
 	}
 }
 
@@ -1896,8 +2067,8 @@ sheet_region_queue_recalc (Sheet const *sheet, GnmRange const *r)
 	g_return_if_fail (IS_SHEET (sheet));
 	g_return_if_fail (sheet->deps != NULL);
 
-	sb = r ? BUCKET_OF_ROW (r->start.row) : 0;
-	eb = r ? BUCKET_OF_ROW (r->end.row) : sheet->deps->buckets - 1;
+	sb = r ? bucket_of_row (r->start.row) : 0;
+	eb = r ? bucket_of_row (r->end.row) : sheet->deps->buckets - 1;
 
 	/* mark the contained depends dirty non recursively */
 	SHEET_FOREACH_DEPENDENT (sheet, dep, {
@@ -2086,14 +2257,6 @@ cb_single_contained_collect (DependencySingle const *depsingle,
 			}});
 }
 
-static void
-cb_collect_names (GnmNamedExpr *nexpr,
-		  G_GNUC_UNUSED gpointer value,
-		  GSList **l)
-{
-	*l = g_slist_prepend (*l, nexpr);
-}
-
 struct cb_remote_names {
 	GSList *names;
 	Workbook *wb;
@@ -2192,9 +2355,9 @@ dependents_relocate (GnmExprRelocateInfo const *rinfo)
 		(GHFunc) &cb_single_contained_collect,
 		(gpointer)&collect);
 	{
-		int const first = BUCKET_OF_ROW (r->start.row);
+		int const first = bucket_of_row (r->start.row);
 		GHashTable *hash;
-		for (i = BUCKET_OF_ROW (r->end.row); i >= first ; i--) {
+		for (i = bucket_of_row (r->end.row); i >= first ; i--) {
 			hash = sheet->deps->range_hash[i];
 			if (hash != NULL)
 				g_hash_table_foreach (hash,
@@ -2556,7 +2719,7 @@ do_deps_destroy (Sheet *sheet)
 	 * are going to be deleted.  However, it is necessary to catch
 	 * all the different life cycles.
 	 */
-	gnm_named_expr_collection_free (sheet->names);
+	gnm_named_expr_collection_unref (sheet->names);
 	sheet->names = NULL;
 
 	deps = sheet->deps;
@@ -2767,7 +2930,7 @@ dependents_workbook_destroy (Workbook *wb)
 		g_hash_table_destroy (wb->sheet_order_dependents);
 		wb->sheet_order_dependents = NULL;
 	}
-	gnm_named_expr_collection_free (wb->names);
+	gnm_named_expr_collection_unref (wb->names);
 	wb->names = NULL;
 
 	WORKBOOK_FOREACH_SHEET (wb, sheet, do_deps_destroy (sheet););
@@ -2898,7 +3061,7 @@ dynamic_dep_free (DynamicDep *dyn)
 	for (ptr = dyn->ranges ; ptr != NULL ; ptr = ptr->next) {
 		GnmRangeRef *rr = ptr->data;
 		link_unlink_cellrange_dep (&dyn->base, pos,
-					   &rr->a, &rr->b, FALSE);
+					   &rr->a, &rr->b, DEP_LINK_UNLINK);
 		g_free (rr);
 	}
 	g_slist_free (dyn->ranges);
@@ -2928,9 +3091,25 @@ gnm_dep_container_new (Sheet *sheet)
 {
 	GnmDepContainer *deps = g_new (GnmDepContainer, 1);
 
+	if (gnm_debug_flag ("dep-buckets")) {
+		int r, lastb = 0;
+		g_assert (bucket_start_row (0) == 0);
+		g_assert (bucket_end_row (0) >= 0);
+		g_assert (bucket_of_row (0) == 0);
+		for (r = 1; r < gnm_sheet_get_max_rows (sheet); r++) {
+			int b = bucket_of_row (r);
+			if (b > lastb)
+				g_printerr ("%d -> %d\n", r, b);
+			g_assert (b == lastb || b == lastb + 1);
+			g_assert (bucket_start_row (b) <= r);
+			g_assert (r <= bucket_end_row (b));
+			lastb = b;
+		}
+	}
+
 	deps->head = deps->tail = NULL;
 
-	deps->buckets = 1 + BUCKET_OF_ROW (gnm_sheet_get_last_row (sheet));
+	deps->buckets = 1 + bucket_of_row (gnm_sheet_get_last_row (sheet));
 	deps->range_hash  = g_new0 (GHashTable *, deps->buckets);
 	deps->range_pool  = go_mem_chunk_new ("range pool",
 					       sizeof (DependencyRange),
@@ -2952,7 +3131,7 @@ gnm_dep_container_new (Sheet *sheet)
 void
 gnm_dep_container_resize (GnmDepContainer *deps, int rows)
 {
-	int i, buckets = 1 + BUCKET_OF_ROW (rows - 1);
+	int i, buckets = 1 + bucket_of_row (rows - 1);
 
 	for (i = buckets; i < deps->buckets; i++) {
 		GHashTable *hash = deps->range_hash[i];
@@ -3001,12 +3180,18 @@ dependent_debug_name_for_sheet (GnmDependent const *dep, Sheet *sheet,
 	t = dependent_type (dep);
 	klass = g_ptr_array_index (dep_classes, t);
 	klass->debug_name (dep, target);
+
+	if (dependent_has_pos (dep) && !dependent_is_cell (dep)) {
+		g_string_append_c (target, '@');
+		g_string_append (target, cellpos_as_string (dependent_pos (dep)));
+	}
 }
 
 
 /**
  * dependent_debug_name:
  * @dep: The dependent we are interested in.
+ * @target: (inout): location to append @dep's name.
  *
  * A useful little debugging utility.
  */
@@ -3018,11 +3203,9 @@ dependent_debug_name (GnmDependent const *dep, GString *target)
 
 
 static void
-dump_range_dep (gpointer key, G_GNUC_UNUSED gpointer value, gpointer sheet_)
+dump_range_dep (DependencyRange const *deprange, Sheet *sheet, GHashTable *alldeps)
 {
-	DependencyRange const *deprange = key;
 	GnmRange const *range = &(deprange->range);
-	Sheet *sheet = sheet_;
 	GString *target = g_string_sized_new (10000);
 	gboolean first = TRUE;
 
@@ -3035,6 +3218,7 @@ dump_range_dep (gpointer key, G_GNUC_UNUSED gpointer value, gpointer sheet_)
 			first = FALSE;
 		else
 			g_string_append (target, ", ");
+		g_hash_table_remove (alldeps, dep);
 		dependent_debug_name_for_sheet (dep, sheet, target);
 	});
 	g_string_append_c (target, ')');
@@ -3044,10 +3228,8 @@ dump_range_dep (gpointer key, G_GNUC_UNUSED gpointer value, gpointer sheet_)
 }
 
 static void
-dump_single_dep (gpointer key, G_GNUC_UNUSED gpointer value, gpointer sheet_)
+dump_single_dep (DependencySingle *depsingle, Sheet *sheet, GHashTable *alldeps)
 {
-	DependencySingle *depsingle = key;
-	Sheet *sheet = sheet_;
 	GString *target = g_string_sized_new (10000);
 	gboolean first = TRUE;
 
@@ -3060,6 +3242,7 @@ dump_single_dep (gpointer key, G_GNUC_UNUSED gpointer value, gpointer sheet_)
 			first = FALSE;
 		else
 			g_string_append (target, ", ");
+		g_hash_table_remove (alldeps, dep);
 		dependent_debug_name_for_sheet (dep, sheet, target);
 	});
 
@@ -3068,11 +3251,8 @@ dump_single_dep (gpointer key, G_GNUC_UNUSED gpointer value, gpointer sheet_)
 }
 
 static void
-dump_dynamic_dep (gpointer key, G_GNUC_UNUSED gpointer value,
-		  G_GNUC_UNUSED gpointer closure)
+dump_dynamic_dep (GnmDependent *dep, DynamicDep *dyn, GHashTable *alldeps)
 {
-	GnmDependent *dep = key;
-	DynamicDep *dyn = value;
 	GSList *l;
 	GnmParsePos pp;
 	GnmConventionsOut out;
@@ -3087,6 +3267,7 @@ dump_dynamic_dep (gpointer key, G_GNUC_UNUSED gpointer value,
 
 	g_string_append (out.accum, "    ");
 	dependent_debug_name (dep, out.accum);
+	g_hash_table_remove (alldeps, dep); // ???
 	g_string_append (out.accum, " -> ");
 	dependent_debug_name (&dyn->base, out.accum);
 	g_string_append (out.accum, " { c=");
@@ -3114,6 +3295,7 @@ dump_dynamic_dep (gpointer key, G_GNUC_UNUSED gpointer value,
 /**
  * gnm_dep_container_dump:
  * @deps:
+ * @sheet:
  *
  * A useful utility for checking the state of the dependency data structures.
  */
@@ -3122,46 +3304,64 @@ gnm_dep_container_dump (GnmDepContainer const *deps,
 			Sheet *sheet)
 {
 	int i;
+	GHashTable *alldeps;
 
 	g_return_if_fail (deps != NULL);
 
 	gnm_dep_container_sanity_check (deps);
 
-	for (i = deps->buckets - 1; i >= 0 ; i--) {
+	alldeps = g_hash_table_new (g_direct_hash, g_direct_equal);
+	SHEET_FOREACH_DEPENDENT (sheet, dep, g_hash_table_insert (alldeps, dep, dep););
+
+	for (i = 0; i < deps->buckets; i++) {
 		GHashTable *hash = deps->range_hash[i];
 		if (hash != NULL && g_hash_table_size (hash) > 0) {
+			GHashTableIter hiter;
+			gpointer key;
+
 			g_printerr ("  Bucket %d (rows %d-%d): Range hash size %d: range over which cells in list depend\n",
 				    i,
-				    BUCKET_START_ROW (i) + 1,
-				    BUCKET_END_ROW (i) + 1,
+				    bucket_start_row (i) + 1,
+				    bucket_end_row (i) + 1,
 				    g_hash_table_size (hash));
-			g_hash_table_foreach (hash,
-					      dump_range_dep,
-					      sheet);
+			g_hash_table_iter_init (&hiter, hash);
+			while (g_hash_table_iter_next (&hiter, &key, NULL)) {
+				DependencyRange *deprange = key;
+				dump_range_dep (deprange, sheet, alldeps);
+			}
 		}
 	}
 
 	if (deps->single_hash && g_hash_table_size (deps->single_hash) > 0) {
+		GHashTableIter hiter;
+		gpointer key;
+
 		g_printerr ("  Single hash size %d: cell on which list of cells depend\n",
 			    g_hash_table_size (deps->single_hash));
-		g_hash_table_foreach (deps->single_hash,
-				      dump_single_dep,
-				      sheet);
+
+		g_hash_table_iter_init (&hiter, deps->single_hash);
+		while (g_hash_table_iter_next (&hiter, &key, NULL)) {
+			DependencySingle *depsingle = key;
+			dump_single_dep (depsingle, sheet, alldeps);
+		}
 	}
 
 	if (deps->dynamic_deps && g_hash_table_size (deps->dynamic_deps) > 0) {
+		GHashTableIter hiter;
+		gpointer key, value;
+
 		g_printerr ("  Dynamic hash size %d: cells that depend on dynamic dependencies\n",
 			    g_hash_table_size (deps->dynamic_deps));
-		g_hash_table_foreach (deps->dynamic_deps,
-				      dump_dynamic_dep, NULL);
+		g_hash_table_iter_init (&hiter, deps->dynamic_deps);
+		while (g_hash_table_iter_next (&hiter, &key, &value)) {
+			GnmDependent *dep = key;
+			DynamicDep *dyn = value;
+			dump_dynamic_dep (dep, dyn, alldeps);
+		}
 	}
 
 	if (deps->referencing_names && g_hash_table_size (deps->referencing_names) > 0) {
-		GSList *l, *names = NULL;
-
-		g_hash_table_foreach (deps->referencing_names,
-				      (GHFunc)cb_collect_names,
-				      &names);
+		GList *l, *names = g_hash_table_get_keys (deps->referencing_names);
 
 		g_printerr ("  Names whose expressions explicitly reference this sheet\n    ");
 		for (l = names; l; l = l->next) {
@@ -3170,8 +3370,34 @@ gnm_dep_container_dump (GnmDepContainer const *deps,
 				    expr_name_name (nexpr),
 				    l->next ? ", " : "\n");
 		}
-		g_slist_free (names);
+		g_list_free (names);
 	}
+
+	if (g_hash_table_size (alldeps) > 0) {
+		GHashTableIter hiter;
+		gpointer key;
+
+		g_printerr ("  Dependencies of sheet not listed above:\n");
+		g_hash_table_iter_init (&hiter, alldeps);
+		while (g_hash_table_iter_next (&hiter, &key, NULL)) {
+			GnmDependent *dep = key;
+			GString *nstr = g_string_new (NULL);
+			GnmParsePos pp;
+			char *estr;
+
+			parse_pos_init_dep (&pp, dep);
+			estr = dep->texpr
+				? gnm_expr_top_as_string (dep->texpr, &pp, sheet_get_conventions (dep->sheet))
+				: g_strdup ("(null)");
+
+			dependent_debug_name (dep, nstr);
+			g_printerr ("    %s: %s\n", nstr->str, estr);
+			g_string_free (nstr, TRUE);
+			g_free (estr);
+		}
+	}
+
+	g_hash_table_destroy (alldeps);
 }
 
 void
