@@ -1,4 +1,3 @@
-/* vim: set sw=8: -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*
  * dialog-analysis-tool-frequency.c:
  *
@@ -18,16 +17,15 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ * along with this program; if not, see <https://www.gnu.org/licenses/>.
  */
 
 #include <gnumeric-config.h>
 #include <glib/gi18n-lib.h>
 #include <gnumeric.h>
-#include "dialogs.h"
-#include "analysis-frequency.h"
-#include "analysis-tools.h"
+#include <dialogs/dialogs.h>
+#include <tools/analysis-frequency.h>
+#include <tools/analysis-tools.h>
 
 #include <workbook.h>
 #include <workbook-control.h>
@@ -36,8 +34,8 @@
 #include <gui-util.h>
 #include <parse-util.h>
 #include <gnm-format.h>
-#include <tool-dialogs.h>
-#include <dao-gui-utils.h>
+#include <dialogs/tool-dialogs.h>
+#include <dialogs/dao-gui-utils.h>
 #include <sheet.h>
 #include <expr.h>
 #include <number-match.h>
@@ -45,13 +43,12 @@
 #include <selection.h>
 #include <value.h>
 #include <commands.h>
-#include "help.h"
+#include <dialogs/help.h>
 
 #include <widgets/gnm-dao.h>
-#include <widgets/gnumeric-expr-entry.h>
+#include <widgets/gnm-expr-entry.h>
 
 #include <string.h>
-#include <gtk/gtk.h>
 
 #define FREQUENCY_KEY      "analysistools-frequency-dialog"
 
@@ -69,7 +66,7 @@ static char const * const chart_group[] = {
 };
 
 typedef struct {
-	GenericToolState base;
+	GnmGenericToolState base;
 	GtkWidget *predetermined_button;
 	GtkWidget *calculated_button;
 	GtkEntry  *n_entry;
@@ -155,7 +152,7 @@ frequency_tool_ok_clicked_cb (G_GNUC_UNUSED GtkWidget *button,
 	GtkWidget *w;
 
 	data = g_new0 (analysis_tools_data_frequency_t, 1);
-	dao  = parse_output ((GenericToolState *)state, NULL);
+	dao  = parse_output ((GnmGenericToolState *)state, NULL);
 
 	data->base.input = gnm_expr_entry_parse_as_list (
 		GNM_EXPR_ENTRY (state->base.input_entry), state->base.sheet);
@@ -255,7 +252,7 @@ dialog_frequency_tool (WBCGtk *wbcg, Sheet *sheet)
 
 	if (dialog_tool_init (&state->base, wbcg, sheet,
 			      GNUMERIC_HELP_LINK_FREQUENCY,
-			      "frequency.ui", "Frequency",
+			      "res:ui/frequency.ui", "Frequency",
 			      _("Could not create the Frequency Tool dialog."),
 			      FREQUENCY_KEY,
 			      G_CALLBACK (frequency_tool_ok_clicked_cb), NULL,
@@ -292,7 +289,7 @@ dialog_frequency_tool (WBCGtk *wbcg, Sheet *sheet)
 
 	gnm_dao_set_put (GNM_DAO (state->base.gdao), TRUE, TRUE);
 	frequency_tool_update_sensitivity_cb (NULL, state);
-	tool_load_selection ((GenericToolState *)state, TRUE);
+	tool_load_selection ((GnmGenericToolState *)state, TRUE);
 
 	gtk_widget_set_sensitive (GTK_WIDGET (state->n_entry), FALSE);
 	gtk_widget_set_sensitive (state->calculated_button, FALSE);
