@@ -1,4 +1,3 @@
-/* vim: set sw=8: -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*
  * dialog-autosave.c:
  *
@@ -23,8 +22,8 @@
  **/
 #include <gnumeric-config.h>
 #include <gnumeric.h>
-#include "dialogs.h"
-#include "help.h"
+#include <dialogs/dialogs.h>
+#include <dialogs/help.h>
 #include <workbook.h>
 #include <workbook-control.h>
 #include <wbc-gtk.h>
@@ -33,7 +32,6 @@
 #include <goffice/goffice.h>
 #include <glib/gi18n-lib.h>
 
-#include <gtk/gtk.h>
 
 typedef struct {
 	GtkWidget *dialog;
@@ -123,7 +121,7 @@ dialog_autosave (WBCGtk *wbcg)
 
 	if (gnm_dialog_raise_if_exists (wbcg, AUTOSAVE_KEY))
 		return;
-	gui = gnm_gtk_builder_load ("autosave.ui", NULL, GO_CMD_CONTEXT (wbcg));
+	gui = gnm_gtk_builder_load ("res:ui/autosave.ui", NULL, GO_CMD_CONTEXT (wbcg));
         if (gui == NULL)
                 return;
 
