@@ -274,7 +274,7 @@ cb_page_select (G_GNUC_UNUSED GtkNotebook *notebook,
 static void
 cb_notebook_destroy (GtkWidget *nb, gpointer page_sig_ptr)
 {
-	g_signal_handler_disconnect (nb, GPOINTER_TO_UINT (page_sig_ptr));
+	g_signal_handler_disconnect (nb, GPOINTER_TO_SIZE (page_sig_ptr));
 }
 
 /*
@@ -1945,9 +1945,9 @@ fmt_dialog_init_validation_page (FormatState *state)
 		parse_pos_init (&pp, state->sheet->workbook, state->sheet,
 			state->sv->edit_pos.col, state->sv->edit_pos.row);
 		gnm_expr_entry_load_from_expr (state->validation.expr0.entry,
-					       v->deps[0].texpr, &pp);
+					       v->deps[0].base.texpr, &pp);
 		gnm_expr_entry_load_from_expr (state->validation.expr1.entry,
-					       v->deps[1].texpr, &pp);
+					       v->deps[1].base.texpr, &pp);
 	}
 
 	cb_validation_sensitivity (NULL, state);
@@ -2276,7 +2276,7 @@ fmt_dialog_impl (FormatState *state, FormatDialogPosition_t pageno, gint pages)
 		NULL
 	};
 
-	int page_signal;
+	gulong page_signal;
 	int i, selected;
 	char const *name;
 	gboolean has_back;
@@ -2325,7 +2325,7 @@ fmt_dialog_impl (FormatState *state, FormatDialogPosition_t pageno, gint pages)
 		G_CALLBACK (cb_page_select), NULL);
 	g_signal_connect (G_OBJECT (state->notebook),
 		"destroy",
-		G_CALLBACK (cb_notebook_destroy), GINT_TO_POINTER (page_signal));
+		G_CALLBACK (cb_notebook_destroy), GSIZE_TO_POINTER (page_signal));
 
 	/* Setup border line pattern buttons & select the 1st button */
 	for (i = MSTYLE_BORDER_TOP; i < MSTYLE_BORDER_DIAGONAL; i++) {
@@ -2477,6 +2477,11 @@ fmt_dialog_impl (FormatState *state, FormatDialogPosition_t pageno, gint pages)
 				gtk_widget_hide (widget);
 		}
 
+	// If we have conflicts then allow setting General right away
+	if (state->conflicts & (1 << MSTYLE_FORMAT))
+		cb_number_format_changed (NULL,
+					  go_format_as_XL (go_format_general ()),
+					  state);
 
 	gnm_restore_window_geometry (GTK_WINDOW (state->dialog),
 					  CELL_FORMAT_KEY);
@@ -2499,7 +2504,7 @@ cb_check_cell_format (GnmCellIter const *iter, gpointer user)
 		gnm_style_set_format (state->style, fmt);
 		return NULL;
 	} else {
-		state->conflicts |= MSTYLE_FORMAT;
+		state->conflicts |= (1 << MSTYLE_FORMAT);
 		return VALUE_TERMINATE;
 	}
 }
@@ -2538,7 +2543,7 @@ fmt_dialog_selection_type (SheetView *sv,
 	state->conflicts = sheet_style_find_conflicts (state->sheet, &r,
 		&(state->style), state->borders);
 
-	if ((state->conflicts & MSTYLE_FORMAT) == 0 &&
+	if ((state->conflicts & (1 << MSTYLE_FORMAT)) == 0 &&
 	    go_format_is_general (gnm_style_get_format (state->style))) {
 		sheet_foreach_cell_in_range (state->sheet,
 					     CELL_ITER_IGNORE_BLANK,
