@@ -1,4 +1,3 @@
-/* vim: set sw=8: -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 
 /*
  * dialog-so-styled.c: Pref dialog for objects with a GOStyle 'style' property
@@ -23,18 +22,17 @@
 
 #include <gnumeric-config.h>
 #include <glib/gi18n-lib.h>
-#include "gnumeric.h"
-#include "dialogs.h"
+#include <gnumeric.h>
+#include <dialogs/dialogs.h>
 
-#include "gui-util.h"
-#include "dialogs/help.h"
-#include "wbc-gtk.h"
-#include "commands.h"
-#include "sheet-object.h"
-#include "gnm-so-line.h"
+#include <gui-util.h>
+#include <dialogs/help.h>
+#include <wbc-gtk.h>
+#include <commands.h>
+#include <sheet-object.h>
+#include <gnm-so-line.h>
 #include <goffice/goffice.h>
-#include <gtk/gtk.h>
-#include <widgets/gnumeric-text-view.h>
+#include <widgets/gnm-text-view.h>
 
 typedef struct {
 	GObject *so;
