@@ -20,53 +20,81 @@
  */
 #include <gnumeric-config.h>
 #include <glib/gi18n-lib.h>
-#include "gnumeric.h"
-#include "expr-deriv.h"
-#include "expr-impl.h"
-#include "func.h"
-#include "value.h"
-#include "sheet.h"
-#include "workbook.h"
-#include "cell.h"
-#include "gutils.h"
-
-/* ------------------------------------------------------------------------- */
-
-static GHashTable *deriv_handlers;
-
-struct DerivInfo {
-	GnmExprDerivHandler handler;
-	GnmExprDerivFlags flags;
-};
+#include <gnumeric.h>
+#include <expr-deriv.h>
+#include <expr-impl.h>
+#include <func.h>
+#include <value.h>
+#include <sheet.h>
+#include <workbook.h>
+#include <cell.h>
+#include <gutils.h>
 
 /* ------------------------------------------------------------------------- */
 
 struct GnmExprDeriv_ {
+	unsigned ref_count;
 	GnmEvalPos var;
 };
 
 /**
- * gnm_expr_deriv_info_new: (skip)
+ * gnm_expr_deriv_info_new:
+ *
+ * Returns: (transfer full): A new #GnmExprDeriv.
  */
 GnmExprDeriv *
 gnm_expr_deriv_info_new (void)
 {
-	return g_new0 (GnmExprDeriv, 1);
+	GnmExprDeriv *res = g_new0 (GnmExprDeriv, 1);
+	res->ref_count = 1;
+	return res;
 }
 
 /**
- * gnm_expr_deriv_info_free: (skip)
+ * gnm_expr_deriv_info_unref:
+ * @deriv: (transfer full) (nullable): #GnmExprDeriv
  */
 void
-gnm_expr_deriv_info_free (GnmExprDeriv *deriv)
+gnm_expr_deriv_info_unref (GnmExprDeriv *deriv)
 {
+	if (!deriv || deriv->ref_count-- > 1)
+		return;
 	g_free (deriv);
 }
 
-void
 /**
- * gnm_expr_deriv_info_set_var: (skip)
+ * gnm_expr_deriv_info_ref:
+ * @deriv: (transfer none) (nullable): #GnmExprDeriv
+ *
+ * Returns: (transfer full) (nullable): a new reference to @deriv.
  */
+GnmExprDeriv *
+gnm_expr_deriv_info_ref (GnmExprDeriv *deriv)
+{
+	if (deriv)
+		deriv->ref_count++;
+	return deriv;
+}
+
+GType
+gnm_expr_deriv_info_get_type (void)
+{
+	static GType t = 0;
+
+	if (t == 0) {
+		t = g_boxed_type_register_static ("GnmExprDeriv",
+			 (GBoxedCopyFunc)gnm_expr_deriv_info_ref,
+			 (GBoxedFreeFunc)gnm_expr_deriv_info_unref);
+	}
+	return t;
+}
+
+/**
+ * gnm_expr_deriv_info_set_var:
+ * @deriv: #GnmExprDeriv
+ * @var: (transfer none): location of variable
+ */
+void
 gnm_expr_deriv_info_set_var (GnmExprDeriv *deriv, GnmEvalPos const *var)
 {
 	deriv->var = *var;
@@ -83,12 +111,22 @@ gnm_value_deriv (GnmValue const *v)
 		return NULL;
 }
 
+static GnmExpr const *madd (GnmExpr const *l, gboolean copyl, GnmExpr const *r, gboolean copyr);
+static GnmExpr const *msub (GnmExpr const *l, gboolean copyl, GnmExpr const *r, gboolean copyr);
+static GnmExpr const *mmul (GnmExpr const *l, gboolean copyl, GnmExpr const *r, gboolean copyr);
+static GnmExpr const *mdiv (GnmExpr const *l, gboolean copyl, GnmExpr const *r, gboolean copyr);
+static GnmExpr const *mneg (GnmExpr const *l, gboolean copyl);
+static GnmExpr const *optimize_sum (GnmExpr const *e);
+
+
+
+
 static gboolean
 is_any_const (GnmExpr const *e, gnm_float *c)
 {
 	GnmValue const *v = gnm_expr_get_constant (e);
 	if (v && VALUE_IS_FLOAT (v)) {
-		*c = value_get_as_float (v);
+		if (c) *c = value_get_as_float (v);
 		return TRUE;
 	} else
 		return FALSE;
@@ -101,6 +139,20 @@ is_const (GnmExpr const *e, gnm_float c)
 	return v && VALUE_IS_FLOAT (v) && value_get_as_float (v) == c;
 }
 
+static gboolean
+is_neg (GnmExpr const *e)
+{
+	return (GNM_EXPR_GET_OPER (e) == GNM_EXPR_OP_UNARY_NEG);
+}
+
+static gboolean
+is_lcmul (GnmExpr const *e, gnm_float *c)
+{
+	return (GNM_EXPR_GET_OPER (e) == GNM_EXPR_OP_MULT &&
+		is_any_const (e->binary.value_a, c));
+}
+
+
 // Optimizing constructor for "+".  Takes ownership of "l" and "r"
 // if the corresponding "copy" argument is false.
 //
@@ -140,6 +192,13 @@ mneg (GnmExpr const *l, gboolean copyl)
 		return gnm_expr_new_constant (value_new_float (-x));
 	}
 
+	if (is_lcmul (l, &x)) {
+		GnmExpr const *res = mmul (gnm_expr_new_constant (value_new_float (-x)), 0,
+					   l->binary.value_b, 1);
+		if (!copyl) gnm_expr_free (l);
+		return res;
+	}
+
 	if (copyl) l = gnm_expr_copy (l);
 	return gnm_expr_new_unary (GNM_EXPR_OP_UNARY_NEG, l);
 }
@@ -193,6 +252,26 @@ mmul (GnmExpr const *l, gboolean copyl, GnmExpr const *r, gboolean copyr)
 		return mneg (r, copyr);
 	}
 
+	if (is_neg (l)) {
+		GnmExpr const *res = mneg (mmul (l->unary.value, 1, r, copyr), 0);
+		if (!copyl) gnm_expr_free (l);
+		return res;
+	}
+
+	if (is_neg (r)) {
+		GnmExpr const *res = mneg (mmul (l, copyl, r->unary.value, 1), 0);
+		if (!copyr) gnm_expr_free (r);
+		return res;
+	}
+
+	if (is_lcmul (l, NULL)) {
+		GnmExpr const *res = mmul (l->binary.value_a, 1,
+					   mmul (l->binary.value_b, 1,
+						 r, copyr), 0);
+		if (!copyl) gnm_expr_free (l);
+		return res;
+	}
+
 	if (copyl) l = gnm_expr_copy (l);
 	if (copyr) r = gnm_expr_copy (r);
 	return gnm_expr_new_binary (l, GNM_EXPR_OP_MULT, r);
@@ -236,6 +315,83 @@ mexp (GnmExpr const *l, gboolean copyl, GnmExpr const *r, gboolean copyr)
 	return gnm_expr_new_binary (l, GNM_EXPR_OP_EXP, r);
 }
 
+static GnmExpr const *
+msum (GnmExprList *as)
+{
+	GnmFunc *fsum = gnm_func_lookup_or_add_placeholder ("SUM");
+	GnmExpr const *res = gnm_expr_new_funcall (fsum, as);
+	GnmExpr const *opt = optimize_sum (res);
+
+	if (opt) {
+		gnm_expr_free (res);
+		res = opt;
+	}
+
+	return res;
+}
+
+static GnmExpr const *
+optimize_sum (GnmExpr const *e)
+{
+	int argc = e->func.argc;
+	GnmExprConstPtr *argv = e->func.argv;
+	gboolean all_neg = (argc > 0);
+	gboolean all_lcmul = (argc > 0);
+	gnm_float cl = 0;
+	int i;
+
+	for (i = 0; i < argc; i++) {
+		GnmExpr const *a = argv[i];
+		gnm_float x;
+
+		all_neg = all_neg && is_neg (a);
+
+		all_lcmul = all_lcmul &&
+			is_lcmul (a, i ? &x : &cl) &&
+			(i == 0 || cl == x);
+	}
+
+	if (all_neg) {
+		GnmExprList *as = NULL;
+		for (i = argc; i-- > 0;) {
+			GnmExpr const *a = argv[i];
+			as = g_slist_prepend (as, (gpointer)gnm_expr_copy (a->unary.value));
+		}
+		return mneg (msum (as), 0);
+	}
+
+	if (all_lcmul) {
+		GnmExprList *as = NULL;
+		for (i = argc; i-- > 0;) {
+			GnmExpr const *a = argv[i];
+			as = g_slist_prepend (as, (gpointer)gnm_expr_copy (a->binary.value_b));
+		}
+		return mmul (gnm_expr_new_constant (value_new_float (cl)), 0,
+			     msum (as), 0);
+	}
+
+	return NULL;
+}
+
+static GnmExpr const *
+optimize (GnmExpr const *e)
+{
+	GnmExprOp op = GNM_EXPR_GET_OPER (e);
+
+	switch (op) {
+	case GNM_EXPR_OP_FUNCALL: {
+		GnmFunc *f = gnm_expr_get_func_def (e);
+		GnmFunc *fsum = gnm_func_lookup_or_add_placeholder ("SUM");
+
+		if (f == fsum)
+			return optimize_sum (e);
+		return NULL;
+	}
+	default:
+		return NULL;
+	}
+}
+
 /* ------------------------------------------------------------------------- */
 
 struct cb_arg_collect {
@@ -255,8 +411,8 @@ cb_arg_collect (GnmCellIter const *iter, gpointer user_)
 			  cell->pos.col, cell->pos.row,
 			  FALSE);
 	parse_pos_init_evalpos (&pp, user->ep);
-	// gnm_cellref_set_col_ar (&cr, &pp, user->cr0->col_relative);
-	// gnm_cellref_set_row_ar (&cr, &pp, user->cr0->row_relative);
+	gnm_cellref_set_col_ar (&cr, &pp, user->cr0->col_relative);
+	gnm_cellref_set_row_ar (&cr, &pp, user->cr0->row_relative);
 	user->args = gnm_expr_list_prepend
 		(user->args,
 		 (gpointer)gnm_expr_new_cellref (&cr));
@@ -269,7 +425,8 @@ cb_arg_collect (GnmCellIter const *iter, gpointer user_)
  * @ep: evaluation position
  * @info: extra information, not currently used
  *
- * Returns: (transfer full): list of expressions expanded from @expr
+ * Returns: (type GSList) (transfer full) (element-type GnmExpr): list of
+ * expressions expanded from @expr
  */
 GnmExprList *
 gnm_expr_deriv_collect (GnmExpr const *expr,
@@ -298,7 +455,7 @@ gnm_expr_deriv_collect (GnmExpr const *expr,
 						&user);
 	}
 
-	return user.args;
+	return g_slist_reverse (user.args);
 }
 
 /* ------------------------------------------------------------------------- */
@@ -318,7 +475,15 @@ gnm_expr_deriv_collect (GnmExpr const *expr,
 
 #define COMMON_BINARY_END }
 
-
+/**
+ * gnm_expr_deriv:
+ * @expr: #GnmExpr
+ * @ep: position for @expr
+ * @info: Derivative information
+ *
+ * Returns: (transfer full) (nullable): the derivative of @expr with respect
+ * to @info.
+ */
 GnmExpr const *
 gnm_expr_deriv (GnmExpr const *expr,
 		GnmEvalPos const *ep,
@@ -387,9 +552,9 @@ gnm_expr_deriv (GnmExpr const *expr,
 	case GNM_EXPR_OP_EXP: {
 		COMMON_BINARY_START
 		GnmFunc *fln = gnm_func_lookup ("ln", NULL);
-		GnmValue const *vb = gnm_expr_get_constant (b);
-		if (vb && VALUE_IS_FLOAT (vb)) {
-			GnmExpr const *bm1 = gnm_expr_new_constant (value_new_float (value_get_as_float (vb) - 1));
+		gnm_float cb;
+		if (is_any_const (b, &cb)) {
+			GnmExpr const *bm1 = gnm_expr_new_constant (value_new_float (cb - 1));
 			GnmExpr const *t1 = mexp (a, 1, bm1, 0);
 			gnm_expr_free (db);
 			return mmul (mmul (b, 1, t1, 0), 0, da, 0);
@@ -402,32 +567,22 @@ gnm_expr_deriv (GnmExpr const *expr,
 				 gnm_expr_new_funcall1 (fln, gnm_expr_copy (a)), 0);
 			GnmExpr const *s = madd (t1, 0, t2, 0);
 			return mmul (expr, 1, s, 0);
-		} else
+		} else {
+		        gnm_expr_free (da);
+			gnm_expr_free (db);
 			return NULL;
+		}
 		COMMON_BINARY_END
 	}
 
 	case GNM_EXPR_OP_FUNCALL: {
 		GnmFunc *f = gnm_expr_get_func_def (expr);
-		struct DerivInfo const *di = deriv_handlers
-			? g_hash_table_lookup (deriv_handlers, f)
-			: NULL;
-		GnmExpr const *res = di
-			? di->handler (expr, ep, info)
-			: NULL;
-		if (!res)
-			return NULL;
-
-		if (di->flags & GNM_EXPR_DERIV_CHAIN) {
-			GnmExpr const *e2 =
-				gnm_expr_deriv (gnm_expr_get_func_arg (expr, 0), ep, info);
-			if (!e2) {
-				gnm_expr_free (res);
-				return NULL;
-			}
-			res = mmul (res, 0, e2, 0);
+		GnmExpr const *res = gnm_func_derivative (f, expr, ep, info);
+		GnmExpr const *opt = res ? optimize (res) : NULL;
+		if (opt) {
+			gnm_expr_free (res);
+			res = opt;
 		}
-
 		return res;
 	}
 
@@ -454,7 +609,7 @@ gnm_expr_deriv (GnmExpr const *expr,
 
 		cell = sheet_cell_get (sheet, r.col, r.row);
 		if (!cell)
-			return gnm_expr_new_constant (value_new_float (1));
+			return gnm_expr_new_constant (value_new_float (0));
 		if (!gnm_cell_has_expr (cell))
 			return gnm_value_deriv (cell->value);
 
@@ -497,6 +652,15 @@ gnm_expr_deriv (GnmExpr const *expr,
 
 /* ------------------------------------------------------------------------- */
 
+/**
+ * gnm_expr_top_deriv:
+ * @texpr: Expression
+ * @ep: Evaluation position
+ * @info: Derivative information
+ *
+ * Returns: (transfer full) (nullable): The derivative of @texpr with
+ * respect to @info.
+ */
 GnmExprTop const *
 gnm_expr_top_deriv (GnmExprTop const *texpr,
 		    GnmEvalPos const *ep,
@@ -510,15 +674,17 @@ gnm_expr_top_deriv (GnmExprTop const *texpr,
 
 	expr = gnm_expr_deriv (texpr->expr, ep, info);
 	if (gnm_debug_flag ("deriv")) {
-		GnmParsePos pp;
+		GnmParsePos pp, ppvar;
 		char *s;
 		Sheet *sheet = ep->sheet;
 		GnmConventions const *convs = sheet_get_conventions (sheet);
 
+		parse_pos_init_evalpos (&ppvar, &info->var);
 		parse_pos_init_evalpos (&pp, ep);
+
 		s = gnm_expr_top_as_string (texpr, &pp, convs);
 		g_printerr ("Derivative of %s with respect to %s:%s",
-			    s, parsepos_as_string (&pp),
+			    s, parsepos_as_string (&ppvar),
 			    expr ? "\n" : " cannot compute.\n");
 		g_free (s);
 		if (expr) {
@@ -531,6 +697,14 @@ gnm_expr_top_deriv (GnmExprTop const *texpr,
 	return gnm_expr_top_new (expr);
 }
 
+/**
+ * gnm_expr_cell_deriv:
+ * @y: Result cell
+ * @x: Variable cell
+ *
+ * Returns: (transfer full) (nullable): The derivative of cell @y with
+ * respect to cell @x.
+ */
 GnmExprTop const *
 gnm_expr_cell_deriv (GnmCell *y, GnmCell *x)
 {
@@ -550,11 +724,19 @@ gnm_expr_cell_deriv (GnmCell *y, GnmCell *x)
 
 	res = gnm_expr_top_deriv (y->base.texpr, &ep, info);
 
-	gnm_expr_deriv_info_free (info);
+	gnm_expr_deriv_info_unref (info);
 
 	return res;
 }
 
+/**
+ * gnm_expr_cell_deriv_value:
+ * @y: Result cell
+ * @x: Variable cell
+ *
+ * Returns: The derivative of cell @y with respect to cell @x at the
+ * current value of @x.  Returns NaN on error.
+ */
 gnm_float
 gnm_expr_cell_deriv_value (GnmCell *y, GnmCell *x)
 {
@@ -583,45 +765,42 @@ gnm_expr_cell_deriv_value (GnmCell *y, GnmCell *x)
 /* ------------------------------------------------------------------------- */
 
 /**
- * gnm_expr_deriv_install_handler:
- * @func: the function being given a handler
- * @h: (scope async): #GnmExprDerivHandler
- * @flags: 
+ * gnm_expr_deriv_chain:
+ * @expr: #GnmExpr for a function call with one argument
+ * @deriv: (transfer full) (nullable): Derivative of @expr's function.
+ * @ep: position for @expr
+ * @info: Derivative information
+ *
+ * Applies the chain rule to @expr.
+ *
+ * Returns: (transfer full) (nullable): the derivative of @expr with respect
+ * to @info.
  */
-void
-gnm_expr_deriv_install_handler (GnmFunc *func, GnmExprDerivHandler h,
-				GnmExprDerivFlags flags)
+GnmExpr const *
+gnm_expr_deriv_chain (GnmExpr const *expr,
+		      GnmExpr const *deriv,
+		      GnmEvalPos const *ep,
+		      GnmExprDeriv *info)
 {
-	struct DerivInfo *data;
+	GnmExpr const *deriv2;
 
-	if (!deriv_handlers) {
-		deriv_handlers = g_hash_table_new_full
-			(g_direct_hash, g_direct_equal,
-			 NULL, g_free);
+	if (!deriv)
+		return NULL;
+
+	deriv2 = gnm_expr_deriv (gnm_expr_get_func_arg (expr, 0), ep, info);
+	if (!deriv2) {
+		gnm_expr_free (deriv);
+		return NULL;
 	}
 
-	data = g_new (struct DerivInfo, 1);
-	data->handler = h;
-	data->flags = flags;
-
-	g_hash_table_replace (deriv_handlers, func, data);
-}
-
-void
-gnm_expr_deriv_uninstall_handler (GnmFunc *func)
-{
-	g_hash_table_remove (deriv_handlers, func);
+	return mmul (deriv, 0, deriv2, 0);
 }
 
 /* ------------------------------------------------------------------------- */
 
 void
-_gnm_expr_deriv_shutdown (void)
+gnm_expr_deriv_shutdown_ (void)
 {
-	if (deriv_handlers) {
-		g_hash_table_destroy (deriv_handlers);
-		deriv_handlers = NULL;
-	}
 }
 
 /* ------------------------------------------------------------------------- */
