@@ -848,6 +848,8 @@ handle_empty (GnmValue *res, GnmExprEvalFlags flags)
  *
  * Always release the value passed in.
  *
+ * NOTE: This should match link_unlink_constant.
+ *
  * Return value:
  *     If the intersection succeeded return a duplicate of the value
  *     at the intersection point.  This value needs to be freed.
@@ -883,20 +885,21 @@ value_intersection (GnmValue *v, GnmEvalPos const *pos)
 			col = r.start.col;
 			row = r.start.row;
 			found = TRUE;
-		} else if (r.start.row == r.end.row) {
-			if (r.start.col <= col && col <= r.end.col) {
-				row = r.start.row;
-				found = TRUE;
-			} else if (r.start.col == r.end.col) {
-				col = r.start.col;
-				row = r.start.row;
-				found = TRUE;
-			}
-		} else if (r.start.col == r.end.col) {
-			if (r.start.row <= row && row <= r.end.row) {
-				col = r.start.col;
-				found = TRUE;
-			}
+		} else if (range_is_singleton (&r)) {
+			// A single cell
+			col = r.start.col;
+			row = r.start.row;
+			found = TRUE;
+		} else if (r.start.row == r.end.row &&
+			   r.start.col <= col && col <= r.end.col) {
+			// A horizontal sliver
+			row = r.start.row;
+			found = TRUE;
+		} else if (r.start.col == r.end.col &&
+			   r.start.row <= row && row <= r.end.row) {
+			// A vertical sliver
+			col = r.start.col;
+			found = TRUE;
 		}
 		if (found) {
 			GnmCell *cell = sheet_cell_get (
@@ -1122,7 +1125,7 @@ bin_array_iter_a (GnmEvalPos const *ep,
 {
 	BinOpImplicitIteratorState iter_info;
 
-	/* a must be a cellrange or array, it can not be NULL */
+	/* a must be a cellrange or array, it cannot be NULL */
 	iter_info.ep   = ep;
 	iter_info.func = func;
 	iter_info.user_data = (gpointer) expr;
@@ -2735,7 +2738,7 @@ do_expr_walk (GnmExpr const *expr, GnmExprWalkerFunc walker, GnmExprWalk *data)
  * @walker: (scope call): callback for each sub-expression
  * @user: user data pointer
  *
- * Returns: (transfer full) (allow-none): transformed expression.
+ * Returns: (transfer full) (nullable): transformed expression.
  *
  * This function walks the expression and calls the walker function for
  * each subexpression.  If the walker returns a non-%NULL expression,
@@ -2902,7 +2905,7 @@ gnm_expr_sharer_new (void)
 }
 
 void
-gnm_expr_sharer_destroy (GnmExprSharer *es)
+gnm_expr_sharer_unref (GnmExprSharer *es)
 {
 	if (!es || es->ref_count-- > 1)
 		return;
@@ -2925,7 +2928,7 @@ gnm_expr_sharer_get_type (void)
 	if (t == 0) {
 		t = g_boxed_type_register_static ("GnmExprSharer",
 			 (GBoxedCopyFunc)gnm_expr_sharer_ref,
-			 (GBoxedFreeFunc)gnm_expr_sharer_destroy);
+			 (GBoxedFreeFunc)gnm_expr_sharer_unref);
 	}
 	return t;
 }
@@ -3098,6 +3101,33 @@ gnm_expr_top_as_string (GnmExprTop const *texpr,
 	return gnm_expr_as_string (texpr->expr, pp, convs);
 }
 
+// This differs from gnm_expr_as_string in that a top-level set
+// representing multiple expressions is rendered as a comma-separated
+// list of expressions with no outside parenthesis.
+char *
+gnm_expr_top_multiple_as_string  (GnmExprTop const *texpr,
+				  GnmParsePos const *pp,
+				  GnmConventions const *convs)
+{
+	char *res;
+
+	g_return_val_if_fail (GNM_IS_EXPR_TOP (texpr), NULL);
+
+	res = gnm_expr_top_as_string (texpr, pp, convs);
+
+	if (GNM_EXPR_GET_OPER (texpr->expr) == GNM_EXPR_OP_SET) {
+		// Get rid of '(' and ')'.  This is crude and probably should
+		// have made it into convs, but it'll do.
+		size_t l = strlen (res);
+		if (l >= 2 && res[0] == '(' && res[l - 1] == ')') {
+			memmove (res, res + 1, l - 2);
+			res[l - 2] = 0;
+		}
+	}
+
+	return res;
+}
+
 void
 gnm_expr_top_as_gstring (GnmExprTop const *texpr,
 			 GnmConventionsOut *out)
@@ -3340,23 +3370,34 @@ gnm_expr_top_eval (GnmExprTop const *texpr,
 		res = gnm_expr_top_eval_array_corner (texpr, pos, flags);
 	else if (gnm_expr_top_is_array_elem (texpr, NULL, NULL))
 		res = gnm_expr_top_eval_array_elem (texpr, pos, flags);
-	else if ((flags & GNM_EXPR_EVAL_ARRAY_CONTEXT) && !eval_pos_is_array_context (pos)) {
-		// Array context out of the blue.  Fake it.
-		GnmEvalPos pos2;
-		GnmExprTop const *fake = gnm_expr_top_new_array_corner (1, 1, NULL);
-		((GnmExpr *)(fake->expr))->array_corner.expr = texpr->expr; // Patch in our expr
-		pos2 = *pos;
-		pos2.array_texpr = fake;
-		res = gnm_expr_eval (texpr->expr, &pos2, flags);
-		((GnmExpr *)(fake->expr))->array_corner.expr = NULL;
-		gnm_expr_top_unref (fake);
-	} else
+	else
 		res = gnm_expr_eval (texpr->expr, pos, flags);
 	gnm_app_recalc_finish ();
 
 	return res;
 }
 
+GnmValue *
+gnm_expr_top_eval_fake_array (GnmExprTop const *texpr,
+			      GnmEvalPos const *pos,
+			      GnmExprEvalFlags flags)
+{
+	if (eval_pos_is_array_context (pos))
+		return gnm_expr_top_eval (texpr, pos, flags);
+	else {
+		GnmEvalPos pos2 = *pos;
+		GnmExprTop const *fake = gnm_expr_top_new_array_corner (1, 1, NULL);
+		GnmValue *res;
+		((GnmExpr *)(fake->expr))->array_corner.expr = texpr->expr; // Patch in our expr
+		pos2.array_texpr = fake;
+		res = gnm_expr_eval (texpr->expr, &pos2, flags);
+		((GnmExpr *)(fake->expr))->array_corner.expr = NULL;
+		gnm_expr_top_unref (fake);
+		return res;
+	}
+}
+
+
 static GSList *
 gnm_insert_unique (GSList *list, gpointer data)
 {
