@@ -1,4 +1,3 @@
-/* vim: set sw=8: -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*
  * file-autoft.c : Retrieve available autoformat templates/categories
  *
@@ -21,13 +20,13 @@
 
 #include <gnumeric-config.h>
 #include <glib/gi18n-lib.h>
-#include "gnumeric.h"
-#include "file-autoft.h"
+#include <gnumeric.h>
+#include <file-autoft.h>
 
-#include "gutils.h"
-#include "workbook-control.h"
-#include "format-template.h"
-#include "gnumeric-conf.h"
+#include <gutils.h>
+#include <workbook-control.h>
+#include <format-template.h>
+#include <gnumeric-conf.h>
 
 #include <gsf/gsf-impl-utils.h>
 #include <goffice/goffice.h>
