@@ -1,4 +1,3 @@
-/* vim: set sw=8: -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 #ifndef _GNM_SO_LINE_H_
 # define _GNM_SO_LINE_H_
 
@@ -7,7 +6,7 @@
 G_BEGIN_DECLS
 
 #define GNM_SO_LINE_TYPE	(gnm_so_line_get_type ())
-#define IS_GNM_SO_LINE(o)	(G_TYPE_CHECK_INSTANCE_TYPE((o), GNM_SO_LINE_TYPE))
+#define GNM_IS_SO_LINE(o)	(G_TYPE_CHECK_INSTANCE_TYPE((o), GNM_SO_LINE_TYPE))
 GType gnm_so_line_get_type (void);
 
 G_END_DECLS
