@@ -14,9 +14,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
- * USA
+ * along with this program; if not, see <https://www.gnu.org/licenses/>
  */
 
 #ifndef _GNM_SO_PATH_H_
@@ -27,7 +25,7 @@
 G_BEGIN_DECLS
 
 #define GNM_SO_PATH_TYPE  (gnm_so_path_get_type ())
-#define IS_GNM_SO_PATH(o) (G_TYPE_CHECK_INSTANCE_TYPE((o), GNM_SO_PATH_TYPE))
+#define GNM_IS_SO_PATH(o) (G_TYPE_CHECK_INSTANCE_TYPE((o), GNM_SO_PATH_TYPE))
 GType gnm_so_path_get_type (void);
 
 G_END_DECLS
