@@ -197,9 +197,12 @@ gnm_go_data_serialize (GOData const *dat, gpointer user)
 		convs = gnm_conventions_default;
 	}
 
-	res = gnm_expr_top_as_string (dep->texpr,
-				      parse_pos_init_dep (&pp, dep),
-				      convs);
+	parse_pos_init_dep (&pp, dep);
+
+	res = GO_IS_DATA_VECTOR (dat)
+		? gnm_expr_top_multiple_as_string (dep->texpr, &pp, convs)
+		: gnm_expr_top_as_string (dep->texpr, &pp, convs);
+
 #if 0
 	g_printerr ("Serializing %s\n", res);
 #endif
@@ -213,6 +216,7 @@ gnm_go_data_unserialize (GOData *dat, char const *str, gpointer user)
 	GnmExprTop const *texpr;
 	GnmParsePos   pp;
 	GnmDependent *dep = gnm_go_data_get_dep (dat);
+	size_t len;
 
 	if (!convs) {
 		g_warning ("NULL convs in gnm_go_data_serialize");
@@ -233,6 +237,16 @@ gnm_go_data_unserialize (GOData *dat, char const *str, gpointer user)
 	                            GNM_EXPR_PARSE_PERMIT_MULTIPLE_EXPRESSIONS:
 		                    GNM_EXPR_PARSE_DEFAULT,
 				    convs, NULL);
+	// Bummer.  We have managed to create files containing (1,2)
+	// which should be read as a vector.  See #492
+	if (!texpr && GO_IS_DATA_VECTOR (dat) && ((len = strlen (str)) > 2) &&
+	    str[0] == '(' && str[len - 1] == ')') {
+		char *str2 = g_strndup (str + 1, len - 2);
+		texpr = gnm_expr_parse_str (str2, &pp,
+					    GNM_EXPR_PARSE_PERMIT_MULTIPLE_EXPRESSIONS,
+					    convs, NULL);
+		g_free (str2);
+	}
 	if (texpr != NULL) {
 		dependent_set_expr (dep, texpr);
 		gnm_expr_top_unref (texpr);
@@ -441,7 +455,7 @@ gnm_go_data_scalar_debug_name (GnmDependent const *dep, GString *target)
 	g_string_append_printf (target, "GraphScalar%p", (void *)dep);
 }
 
-static DEPENDENT_MAKE_TYPE (gnm_go_data_scalar, NULL)
+static DEPENDENT_MAKE_TYPE (gnm_go_data_scalar, .eval = gnm_go_data_scalar_eval, .debug_name = gnm_go_data_scalar_debug_name)
 
 static void
 gnm_go_data_scalar_init (GObject *obj)
@@ -551,8 +565,10 @@ gnm_go_data_vector_load_len (GODataVector *dat)
 				for (cur = l; cur != NULL; cur = cur->next)
 					value_release (cur->data);
 			}
-			vec->val = gnm_expr_top_eval (vec->dep.texpr, &ep,
-				GNM_EXPR_EVAL_PERMIT_NON_SCALAR | GNM_EXPR_EVAL_PERMIT_EMPTY | GNM_EXPR_EVAL_ARRAY_CONTEXT);
+			vec->val = gnm_expr_top_eval_fake_array
+				(vec->dep.texpr, &ep,
+				 GNM_EXPR_EVAL_PERMIT_NON_SCALAR |
+				 GNM_EXPR_EVAL_PERMIT_EMPTY);
 		}
 		g_slist_free (l);
 	}
@@ -1119,7 +1135,7 @@ gnm_go_data_vector_debug_name (GnmDependent const *dep, GString *target)
 {
 	g_string_append_printf (target, "GraphVector%p", (void *)dep);
 }
-static DEPENDENT_MAKE_TYPE (gnm_go_data_vector, NULL)
+static DEPENDENT_MAKE_TYPE (gnm_go_data_vector, .eval = gnm_go_data_vector_eval, .debug_name = gnm_go_data_vector_debug_name)
 
 static void
 gnm_go_data_vector_init (GObject *obj)
@@ -1485,7 +1501,7 @@ gnm_go_data_matrix_debug_name (GnmDependent const *dep, GString *target)
 {
 	g_string_append_printf (target, "GraphMatrix%p", (void *)dep);
 }
-static DEPENDENT_MAKE_TYPE (gnm_go_data_matrix, NULL)
+static DEPENDENT_MAKE_TYPE (gnm_go_data_matrix, .eval = gnm_go_data_matrix_eval, .debug_name = gnm_go_data_matrix_debug_name)
 
 static void
 gnm_go_data_matrix_init (GObject *obj)
