@@ -166,7 +166,7 @@ cb_item_cursor_animation (GnmItemCursor *ic)
 	if (goc_canvas_get_direction (item->canvas) == GOC_DIRECTION_RTL) {
 		goc_canvas_c2w (item->canvas, ic->outline.x2 / scale, ic->outline.y2 / scale, &x0, &y1);
 		goc_canvas_c2w (item->canvas, ic->outline.x1 / scale, ic->outline.y1 / scale, &x1, &y0);
-		x0--; /* because of the +.5, things are not symetric */
+		x0--; /* because of the +.5, things are not symmetric */
 		x1--;
 	} else {
 		goc_canvas_c2w (item->canvas, ic->outline.x1 / scale, ic->outline.y1 / scale, &x0, &y0);
@@ -294,7 +294,7 @@ item_cursor_draw (GocItem const *item, cairo_t *cr)
 	if (goc_canvas_get_direction (item->canvas) == GOC_DIRECTION_RTL) {
 		goc_canvas_c2w (item->canvas, ic->outline.x2 / scale, ic->outline.y2 / scale, &x0, &y1);
 		goc_canvas_c2w (item->canvas, ic->outline.x1 / scale, ic->outline.y1 / scale, &x1, &y0);
-		x0--; /* because of the +.5, things are not symetric */
+		x0--; /* because of the +.5, things are not symmetric */
 		x1--;
 	} else {
 		goc_canvas_c2w (item->canvas, ic->outline.x1 / scale, ic->outline.y1 / scale, &x0, &y0);
@@ -1082,7 +1082,7 @@ item_cursor_button_pressed (GocItem *item, int button, double x_, double y_)
 		 * call wbcg_edit_finish.
 		 */
 
-		/* scroll wheel events dont have corresponding release events */
+		/* scroll wheel events don't have corresponding release events */
 		if (button > 3)
 			return FALSE;
 
@@ -1091,7 +1091,7 @@ item_cursor_button_pressed (GocItem *item, int button, double x_, double y_)
 			return TRUE;
 
 		if (button != 3) {
-			/* prepare to create fill or drag cursors, but dont until we
+			/* prepare to create fill or drag cursors, but don't until we
 			 * move.  If we did create them here there would be problems
 			 * with race conditions when the new cursors pop into existence
 			 * during a double-click
