@@ -1,8 +1,7 @@
-/* vim: set sw=8: -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 #ifndef _GNM_LIBGNUMERIC_H_
 # define _GNM_LIBGNUMERIC_H_
 
-#include "gnumeric.h"
+#include <gnumeric.h>
 
 G_BEGIN_DECLS
 
@@ -25,11 +24,6 @@ void	     gnm_shutdown	    (void);
 
 GOptionGroup *gnm_get_option_group (void);
 
-GNM_VAR_DECL gboolean	initial_workbook_open_complete;
-
-/* Internal */
-int gnm_dump_func_defs (char const* filename, int dump_type); /* changes as needed */
-
 G_END_DECLS
 
 #endif /* _GNM_LIBGNUMERIC_H_ */
