@@ -31,6 +31,8 @@
 #include <goffice/goffice.h>
 #include <string.h>
 
+static gboolean debug_style_deps;
+
 #define DEBUG_STYLES
 #ifndef USE_MSTYLE_POOL
 #define USE_MSTYLE_POOL 1
@@ -843,7 +845,7 @@ gnm_style_ref (GnmStyle const *style)
  *
  * Unrefs and _potentially frees_ @style.
  * Takes a _const_ pointer to facilitate life cycles.  The const indicates that
- * the content can not be changed, mainly when handling styles that are in the
+ * the content cannot be changed, mainly when handling styles that are in the
  * style hash.
  **/
 void
@@ -982,31 +984,28 @@ gnm_style_linked_sheet_changed (GnmStyle *style)
 	if (elem_is_set (style, MSTYLE_VALIDATION) &&
 	    style->validation &&
 	    gnm_validation_get_sheet (style->validation) != sheet) {
-		GnmValidation *new_v = gnm_validation_dup (style->validation);
-		gnm_validation_set_sheet (new_v, sheet);
+		GnmValidation *new_v = gnm_validation_dup_to (style->validation, sheet);
 		gnm_style_set_validation (style, new_v);
 	}
 
 	if (elem_is_set (style, MSTYLE_HLINK) &&
 	    style->hlink &&
 	    gnm_hlink_get_sheet (style->hlink) != sheet) {
-		GnmHLink *new_l = gnm_hlink_dup (style->hlink);
-		gnm_hlink_set_sheet (new_l, sheet);
+		GnmHLink *new_l = gnm_hlink_dup_to (style->hlink, sheet);
 		gnm_style_set_hlink (style, new_l);
 	}
 
 	if (elem_is_set (style, MSTYLE_CONDITIONS) &&
 	    style->conditions &&
 	    gnm_style_conditions_get_sheet (style->conditions) != sheet) {
-		GnmStyleConditions *new_c = gnm_style_conditions_dup (style->conditions);
-		gnm_style_conditions_set_sheet (new_c, sheet);
+		GnmStyleConditions *new_c = gnm_style_conditions_dup_to (style->conditions, sheet);
 		gnm_style_set_conditions (style, new_c);
 	}
 }
 
 /**
  * gnm_style_link_sheet:
- * @style:
+ * @style: (transfer full):
  * @sheet:
  *
  * ABSORBS a reference to the style and sets the link count to 1.
@@ -1060,15 +1059,6 @@ gnm_style_link (GnmStyle *style)
 	d(("link %p = %d\n", style, style->link_count));
 }
 
-void
-gnm_style_link_multiple (GnmStyle *style, int count)
-{
-	g_return_if_fail (style->link_count > 0);
-
-	style->link_count += count;
-	d(("multiple link %p + %d = %d\n", style, count, style->link_count));
-}
-
 void
 gnm_style_unlink (GnmStyle *style)
 {
@@ -1251,6 +1241,7 @@ gnm_style_cmp (GnmStyle const *a, GnmStyle const *b)
 	return a < b ? -1 : +1;
 }
 
+#undef CMP_TRY_NUMBER_RAW
 #undef CMP_TRY_NUMBER
 #undef CMP_TRY_COLOR
 
@@ -2165,7 +2156,7 @@ gnm_style_get_contents_hidden (GnmStyle const *style)
 /**
  * gnm_style_set_validation:
  * @style: #GnmStyle to change
- * @v: (transfer full): #GnmValidation
+ * @v: (transfer full) (nullable): #GnmValidation
  **/
 void
 gnm_style_set_validation (GnmStyle *style, GnmValidation *v)
@@ -2182,7 +2173,7 @@ gnm_style_set_validation (GnmStyle *style, GnmValidation *v)
  * gnm_style_get_validation:
  * @style: #GnmStyle to query
  *
- * Returns: (transfer none):
+ * Returns: (transfer none) (nullable):
  **/
 GnmValidation const *
 gnm_style_get_validation (GnmStyle const *style)
@@ -2262,7 +2253,7 @@ gnm_style_get_input_msg (GnmStyle const *style)
 /**
  * gnm_style_set_conditions:
  * @style: #GnmStyle to change
- * @sc: (transfer full): #GnmStyleConditions
+ * @sc: (transfer full) (nullable): #GnmStyleConditions
  *
  * This sets conditional style for @style.
  **/
@@ -2314,15 +2305,6 @@ gnm_style_get_cond_style (GnmStyle const *style, int ix)
 }
 
 
-static gboolean
-debug_style_deps (void)
-{
-	static int debug = -1;
-	if (debug < 0)
-		debug = gnm_debug_flag ("style-deps");
-	return debug;
-}
-
 /*
  * Just a simple version for now.  We can also ignore most function
  * calls[1] and self-references[2].
@@ -2364,11 +2346,12 @@ gnm_style_link_dependents (GnmStyle *style, GnmRange const *r)
 		? gnm_style_get_conditions (style)
 		: NULL;
 	if (sc) {
+		GnmParsePos pp;
 		GPtrArray const *conds = gnm_style_conditions_details (sc);
 		guint ui;
-		if (debug_style_deps ())
-			g_printerr ("Linking %s for %p\n",
-				    range_as_string (r), style);
+
+		parse_pos_init (&pp, NULL, sheet, r->start.col, r->start.row);
+
 		for (ui = 0; conds && ui < conds->len; ui++) {
 			GnmStyleCond const *c = g_ptr_array_index (conds, ui);
 			guint ei;
@@ -2376,9 +2359,29 @@ gnm_style_link_dependents (GnmStyle *style, GnmRange const *r)
 			for (ei = 0; ei < 2; ei++) {
 				GnmExprTop const *texpr =
 					gnm_style_cond_get_expr (c, ei);
-				if (!texpr ||
-				    cond_expr_harmless (texpr->expr))
+				char *s = NULL;
+				if (!texpr)
 					continue;
+
+				if (debug_style_deps)
+					s = gnm_expr_top_as_string (texpr, &pp,
+								    sheet_get_conventions (sheet));
+
+				if (cond_expr_harmless (texpr->expr)) {
+					if (debug_style_deps) {
+						g_printerr ("Not linking %s %d:%d for %p: %s (harmless)\n",
+							    range_as_string (r), ui, ei, style, s);
+						g_free (s);
+					}
+					continue;
+				}
+
+				if (debug_style_deps) {
+					g_printerr ("Linking %s %d:%d for %p: %s\n",
+						    range_as_string (r), ui, ei, style, s);
+					g_free (s);
+				}
+
 				if (!style->deps)
 					style->deps = g_ptr_array_new ();
 				gnm_dep_style_dependency
@@ -2415,7 +2418,7 @@ gnm_style_unlink_dependents (GnmStyle *style, GnmRange const *r)
 
 		if (dep->sheet->being_destructed ||
 		    range_contains (r, pos->col, pos->row)) {
-			if (debug_style_deps ())
+			if (debug_style_deps)
 				g_printerr ("Unlinking %s for %p\n",
 					    cellpos_as_string (pos), style);
 			dependent_set_expr (dep, NULL);
@@ -2467,6 +2470,8 @@ add_attr (PangoAttrList *attrs, PangoAttribute *attr)
 /**
  * gnm_style_generate_attrs:
  * @style: style to query
+ * @context: the context for the attributes
+ * @zoom: zoom level
  *
  * Returns: (transfer full): a #PangoAttrList with attributes matching
  * @style.  Attributes where the default will serve are not included.
@@ -2783,6 +2788,8 @@ gnm_style_dump (GnmStyle const *style)
 void
 gnm_style_init (void)
 {
+	debug_style_deps = gnm_debug_flag ("style-deps");
+
 #if USE_MSTYLE_POOL
 	gnm_style_pool =
 		go_mem_chunk_new ("style pool",
