@@ -40,7 +40,7 @@
  *
  * Updates @r to fill @sheet in its entirety.
  *
- * Returns: (skip) (transfer none): @r
+ * Returns: (type void): @r
  */
 GnmRange *
 range_init_full_sheet (GnmRange *r, Sheet const *sheet)
@@ -61,7 +61,7 @@ range_init_full_sheet (GnmRange *r, Sheet const *sheet)
  *
  * Updates @r to span full columns @start_col through @end_col completely.
  *
- * Returns: (skip) (transfer none): @r
+ * Returns: (type void): @r
  */
 GnmRange *
 range_init_cols (GnmRange *r, Sheet const *sheet, int start_col, int end_col)
@@ -82,7 +82,7 @@ range_init_cols (GnmRange *r, Sheet const *sheet, int start_col, int end_col)
  *
  * Updates @r to span full rows @start_row through @end_row completely.
  *
- * Returns: (skip) (transfer none): @r
+ * Returns: (type void): @r
  */
 GnmRange *
 range_init_rows (GnmRange *r, Sheet const *sheet, int start_row, int end_row)
@@ -100,7 +100,7 @@ range_init_rows (GnmRange *r, Sheet const *sheet, int start_row, int end_row)
  *
  * Updates @r to a meaningless range
  *
- * Returns: (skip) (transfer none): @r
+ * Returns: (type void): @r
  */
 GnmRange *
 range_init_invalid (GnmRange *r)
@@ -119,7 +119,7 @@ range_init_invalid (GnmRange *r)
  *
  * Updates @r to be the same as the range part of @rr.
  *
- * Returns: (skip) (transfer none): @r
+ * Returns: (type void): @r
  */
 GnmRange *
 range_init_rangeref (GnmRange *range, GnmRangeRef const *rr)
@@ -141,7 +141,7 @@ range_init_rangeref (GnmRange *range, GnmRangeRef const *rr)
  *
  * Updates @r to be the same as the cell range of @v.
  *
- * Returns: (skip) (transfer none): @r
+ * Returns: (type void): @r
  */
 GnmRange *
 range_init_value (GnmRange *range, GnmValue const *v)
@@ -159,7 +159,7 @@ range_init_value (GnmRange *range, GnmValue const *v)
  *
  * Updates @r to be the singleton range of @pos
  *
- * Returns: (skip) (transfer none): @r
+ * Returns: (type void): @r
  */
 GnmRange *
 range_init_cellpos (GnmRange *r, GnmCellPos const *pos)
@@ -179,7 +179,7 @@ range_init_cellpos (GnmRange *r, GnmCellPos const *pos)
  *
  * Updates @r to start at @start and spanning @cols columns and @rows rows.
  *
- * Returns: (skip) (transfer none): @r
+ * Returns: (type void): @r
  */
 GnmRange *
 range_init_cellpos_size (GnmRange *r,
@@ -203,7 +203,7 @@ range_init_cellpos_size (GnmRange *r,
  * Updates @r to start at (@start_col,@start_row) and end
  * at (@end_col,@end_row).
  *
- * Returns: (skip) (transfer none): @r
+ * Returns: (type void): @r
  */
 GnmRange *
 range_init (GnmRange *r, int start_col, int start_row,
@@ -1279,3 +1279,66 @@ gnm_range_get_type (void)
 			 (GBoxedFreeFunc)g_free);
 	return t;
 }
+
+static gboolean
+merge_ranges (GnmRange *a, GnmRange const *b)
+{
+	if (a->start.row == b->start.row &&
+	    a->end.row == b->end.row &&
+	    a->end.col + 1 >= b->start.col) {
+		// "a" is just left of "b", possibly with overlap
+		a->end.col = MAX (a->end.col, b->end.col);
+		return TRUE;
+	}
+
+	if (a->start.col == b->start.col &&
+	    a->end.col == b->end.col &&
+	    a->end.row + 1 >= b->start.row) {
+		// "a" is just on top of "b", possibly with overlap
+		a->end.row = MAX (a->end.row, b->end.row);
+		return TRUE;
+	}
+
+	if (range_contained (b, a)) {
+		// "b" is inside "a"
+		return TRUE;
+	}
+
+	// Punt.
+	return FALSE;
+}
+
+static gboolean
+try_merge_pair (GArray *arr, unsigned ui1, unsigned ui2)
+{
+	GnmRange *ra = &g_array_index (arr, GnmRange, ui1);
+	GnmRange *rb = &g_array_index (arr, GnmRange, ui2);
+
+	if (merge_ranges (ra, rb)) {
+		g_array_remove_index (arr, ui2);
+		return TRUE;
+	} else
+		return FALSE;
+}
+
+/**
+ * gnm_range_simplify:
+ * @arr: (element-type GnmRange) (inout): array of ranges to simplify
+ *
+ * Simplifies the array of ranges by merging small ranges into larger ones.
+ */
+void
+gnm_range_simplify (GArray *arr)
+{
+	unsigned ui;
+
+	if (arr->len < 2)
+		return;
+
+	g_array_sort (arr, (GCompareFunc) gnm_range_compare);
+	// Two cheap passes through the ranges.
+	for (ui = arr->len - 1; ui > 0; ui--)
+		try_merge_pair (arr, ui - 1, ui);
+	for (ui = arr->len - 1; ui > 0; ui--)
+		try_merge_pair (arr, ui - 1, ui);
+}
