@@ -1,4 +1,3 @@
-/* vim: set sw=8: -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 
 /* session.c
  * Copyright (C) 2003-2006  Andreas J. Guelzow <aguelzow@taliesin.ca>
@@ -14,13 +13,16 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ * along with this program; if not, see <https://www.gnu.org/licenses/>.
  */
 
 #include <gnumeric-config.h>
 
-#include "session.h"
+#include <session.h>
+
+/**
+ * gnm_session_init: (skip)
+ */
 void
 gnm_session_init (char const *argv0)
 {
