@@ -27,6 +27,8 @@
 #include <workbook.h>
 #include <sheet.h>
 #include <sheet-private.h>
+#include <sheet-view.h>
+#include <sheet-control.h>
 #include <cell.h>
 #include <expr.h>
 #include <value.h>
@@ -633,7 +635,6 @@ gnm_filter_add_field (GnmFilter *filter, int i)
 {
 	/* pretend to fill the cell, then clip the X start later */
 	static double const a_offsets[4] = { .0, .0, 1., 1. };
-	int n;
 	GnmRange tmp;
 	SheetObjectAnchor anchor;
 	GnmFilterCombo *fcombo = g_object_new (GNM_FILTER_COMBO_TYPE, NULL);
@@ -646,11 +647,11 @@ gnm_filter_add_field (GnmFilter *filter, int i)
 	sheet_object_set_anchor (GNM_SO (fcombo), &anchor);
 	sheet_object_set_sheet (GNM_SO (fcombo), filter->sheet);
 
-	g_ptr_array_add (filter->fields, NULL);
-	for (n = filter->fields->len; --n > i ; )
-		g_ptr_array_index (filter->fields, n) =
-			g_ptr_array_index (filter->fields, n - 1);
-	g_ptr_array_index (filter->fields, n) = fcombo;
+#ifdef HAVE_G_PTR_ARRAY_INSERT
+	g_ptr_array_insert (filter->fields, i, fcombo);
+#else
+	go_ptr_array_insert (filter->fields, fcombo, i);
+#endif
 	/* We hold a reference to fcombo */
 }
 
@@ -676,13 +677,14 @@ gnm_filter_attach (GnmFilter *filter, Sheet *sheet)
 
 /**
  * gnm_filter_new:
- * @sheet:
- * @r:
+ * @sheet: #Sheet for which to create the filter.
+ * @r: #GnmRange that the filter covers.
+ * @attach: whether to attach the filter.
  *
- * Init a filter and add it to @sheet
+ * Returns: (transfer full): A new filter.
  **/
 GnmFilter *
-gnm_filter_new (Sheet *sheet, GnmRange const *r)
+gnm_filter_new (Sheet *sheet, GnmRange const *r, gboolean attach)
 {
 	GnmFilter	*filter;
 
@@ -695,8 +697,12 @@ gnm_filter_new (Sheet *sheet, GnmRange const *r)
 	filter->r = *r;
 	filter->fields = g_ptr_array_new ();
 
-	/* This creates the initial ref.  */
-	gnm_filter_attach (filter, sheet);
+	if (attach) {
+		/* This creates the initial ref.  */
+		gnm_filter_attach (filter, sheet);
+	} else {
+		gnm_filter_ref (filter);
+	}
 
 	return filter;
 }
@@ -792,12 +798,18 @@ gnm_filter_remove (GnmFilter *filter)
 	}
 	filter->sheet = NULL;
 
-	for (i = 0 ; i < (int)filter->fields->len ; i++) {
+	SHEET_FOREACH_CONTROL
+		(sheet, view, sc, sc_freeze_object_view (sc, TRUE););
+
+	for (i = filter->fields->len; i-- > 0; ) {
 		SheetObject *so = g_ptr_array_index (filter->fields, i);
 		sheet_object_clear_sheet (so);
 		g_object_unref (so);
 	}
 	g_ptr_array_set_size (filter->fields, 0);
+
+	SHEET_FOREACH_CONTROL
+		(sheet, view, sc, sc_freeze_object_view (sc, FALSE););
 }
 
 /**
