@@ -45,6 +45,11 @@
 
 #include <string.h>
 
+static gboolean debug_sheet_objects;
+
+static guint so_create_view_src;
+static GPtrArray *so_create_view_sos;
+
 /* GType code for SheetObjectAnchor */
 static SheetObjectAnchor *
 sheet_object_anchor_copy (SheetObjectAnchor * soa)
@@ -105,6 +110,8 @@ static GQuark	sov_container_quark;
 void
 sheet_object_set_print_flag (SheetObject *so, gboolean *print)
 {
+	g_return_if_fail (GNM_IS_SO (so));
+
 	if (*print)
 		so->flags |= SHEET_OBJECT_PRINT;
 	else
@@ -305,34 +312,6 @@ sheet_object_populate_menu (SheetObject *so, GPtrArray *actions)
 	GNM_SO_CLASS (G_OBJECT_GET_CLASS(so))->populate_menu (so, actions);
 }
 
-/**
- * sheet_objects_max_extent:
- * @sheet:
- *
- * Utility routine to calculate the maximum extent of objects in this sheet.
- */
-static void
-sheet_objects_max_extent (Sheet *sheet)
-{
-	GnmCellPos max_pos = { 0, 0 };
-	GSList *ptr;
-
-	for (ptr = sheet->sheet_objects; ptr != NULL ; ptr = ptr->next ) {
-		SheetObject *so = GNM_SO (ptr->data);
-
-		if (max_pos.col < so->anchor.cell_bound.end.col)
-			max_pos.col = so->anchor.cell_bound.end.col;
-		if (max_pos.row < so->anchor.cell_bound.end.row)
-			max_pos.row = so->anchor.cell_bound.end.row;
-	}
-
-	if (sheet->max_object_extent.col != max_pos.col ||
-	    sheet->max_object_extent.row != max_pos.row) {
-		sheet->max_object_extent = max_pos;
-		sheet_scrollbar_config (sheet);
-	}
-}
-
 void
 sheet_object_set_name (SheetObject *so, const char *name)
 {
@@ -562,12 +541,26 @@ sheet_object_get_sheet (SheetObject const *so)
 	return so->sheet;
 }
 
-static int
-cb_create_views (SheetObject *so)
+static gboolean
+cb_create_views (void)
 {
-	g_object_set_data (G_OBJECT (so), "create_view_handler", NULL);
-	SHEET_FOREACH_CONTROL (so->sheet, view, control,
-		sc_object_create_view (control, so););
+	int pass;
+
+	for (pass = 1; pass <= 3; pass++) {
+		unsigned ui, l = so_create_view_sos->len;
+		for (ui = 0; ui < l; ui++) {
+			SheetObject *so = g_ptr_array_index (so_create_view_sos, ui);
+			SHEET_FOREACH_CONTROL
+				(so->sheet, view, control,
+				 if (pass == 2)
+					 sc_object_create_view (control, so);
+				 else
+					 sc_freeze_object_view (control, pass == 1);
+					);
+		}
+	}
+	g_ptr_array_set_size (so_create_view_sos, 0);
+	so_create_view_src = 0;
 	return FALSE;
 }
 
@@ -577,26 +570,25 @@ cb_create_views (SheetObject *so)
  * @sheet:
  *
  * Adds a reference to the object.
- *
- * Returns: %TRUE if there was a problem
  **/
-gboolean
+void
 sheet_object_set_sheet (SheetObject *so, Sheet *sheet)
 {
-	g_return_val_if_fail (GNM_IS_SO (so), TRUE);
-	g_return_val_if_fail (IS_SHEET (sheet), TRUE);
+	g_return_if_fail (GNM_IS_SO (so));
+	g_return_if_fail (IS_SHEET (sheet));
 
 	if (sheet == so->sheet)
-		return FALSE;
+		return;
 
-	g_return_val_if_fail (so->sheet == NULL, TRUE);
-	g_return_val_if_fail (g_slist_find (sheet->sheet_objects, so) == NULL, TRUE);
+	g_return_if_fail (so->sheet == NULL);
+	if (debug_sheet_objects)
+		g_return_if_fail (g_slist_find (sheet->sheet_objects, so) == NULL);
 
 	so->sheet = sheet;
 	if (SO_CLASS (so)->assign_to_sheet &&
 	    SO_CLASS (so)->assign_to_sheet (so, sheet)) {
 		so->sheet = NULL;
-		return TRUE;
+		return;
 	}
 
 	g_object_ref (so);
@@ -607,15 +599,19 @@ sheet_object_set_sheet (SheetObject *so, Sheet *sheet)
 		sheet_object_anchor_to_pts (&so->anchor, sheet, x);
 		sheet_object_pts_to_anchor (&so->anchor, sheet, x);
 	}
-	/* FIXME : add a flag to sheet to have sheet_update do this */
-	sheet_objects_max_extent (sheet);
 
-	if (NULL == g_object_get_data (G_OBJECT (so), "create_view_handler")) {
-		guint id = g_idle_add ((GSourceFunc) cb_create_views, so);
-		g_object_set_data (G_OBJECT (so), "create_view_handler", GUINT_TO_POINTER (id));
+	sheet->priv->objects_changed = TRUE;
+
+	g_ptr_array_add (so_create_view_sos, so);
+	if (!so_create_view_src) {
+		so_create_view_src =
+			g_timeout_add_full (
+				G_PRIORITY_DEFAULT_IDLE,
+				0,
+				(GSourceFunc)cb_create_views,
+				NULL,
+				NULL);
 	}
-
-	return FALSE;
 }
 
 /**
@@ -629,7 +625,7 @@ void
 sheet_object_clear_sheet (SheetObject *so)
 {
 	GSList *ptr;
-	gpointer view_handler;
+	unsigned ui;
 
 	g_return_if_fail (GNM_IS_SO (so));
 
@@ -642,10 +638,11 @@ sheet_object_clear_sheet (SheetObject *so)
 	g_return_if_fail (ptr != NULL);
 
 	/* clear any pending attempts to create views */
-	view_handler = g_object_get_data (G_OBJECT (so), "create_view_handler");
-	if (NULL != view_handler) {
-		g_source_remove (GPOINTER_TO_UINT (view_handler));
-		g_object_set_data (G_OBJECT (so), "create_view_handler", NULL);
+	for (ui = 0; ui < so_create_view_sos->len; ui++) {
+		if (so == g_ptr_array_index (so_create_view_sos, ui)) {
+			g_ptr_array_remove_index (so_create_view_sos, ui);
+			break;
+		}
 	}
 
 	while (so->realized_list != NULL) {
@@ -663,9 +660,9 @@ sheet_object_clear_sheet (SheetObject *so)
 	so->sheet->sheet_objects = g_slist_remove_link (so->sheet->sheet_objects, ptr);
 	g_slist_free (ptr);
 
-	if (so->anchor.cell_bound.end.col == so->sheet->max_object_extent.col &&
+	if (so->anchor.cell_bound.end.col == so->sheet->max_object_extent.col ||
 	    so->anchor.cell_bound.end.row == so->sheet->max_object_extent.row)
-		sheet_objects_max_extent (so->sheet);
+		so->sheet->priv->objects_changed = TRUE;
 
 	so->sheet = NULL;
 	g_object_unref (so);
@@ -885,7 +882,7 @@ sheet_object_set_anchor (SheetObject *so, SheetObjectAnchor const *anchor)
 
 	so->anchor = *anchor;
 	if (so->sheet != NULL) {
-		sheet_objects_max_extent (so->sheet);
+		so->sheet->priv->objects_changed = TRUE;
 		sheet_object_update_bounds (so, NULL);
 	}
 }
@@ -1180,9 +1177,9 @@ sheet_objects_relocate (GnmExprRelocateInfo const *rinfo, gboolean update,
 		}
 	}
 
-	sheet_objects_max_extent (rinfo->origin_sheet);
+	rinfo->origin_sheet->priv->objects_changed = TRUE;
 	if (change_sheets)
-		sheet_objects_max_extent (rinfo->target_sheet);
+		rinfo->target_sheet->priv->objects_changed = TRUE;
 }
 
 /**
@@ -1486,6 +1483,21 @@ sheet_object_view_set_bounds (SheetObjectView *sov,
 		(klass->set_bounds) (sov, coords, visible);
 }
 
+/**
+ * sheet_object_view_get_item:
+ * @sov: #SheetObjectView
+ *
+ * Returns: (transfer none): the #GocItem implementing @sov
+ **/
+GocItem *
+sheet_object_view_get_item (SheetObjectView *sov)
+{
+	g_return_val_if_fail (GNM_IS_SO_VIEW (sov), NULL);
+
+	return goc_group_get_child (GOC_GROUP (sov), 0);
+}
+
+
 /**
  * sheet_object_view_get_so:
  * @sov: #SheetObjectView
@@ -1920,6 +1932,9 @@ sheet_object_move_do (GSList *objects, GSList *anchors,
 void
 sheet_objects_init (void)
 {
+	debug_sheet_objects = gnm_debug_flag ("sheet-objects");
+	so_create_view_sos = g_ptr_array_new ();
+
 	GNM_SO_LINE_TYPE;
 	GNM_SO_FILLED_TYPE;
 	GNM_SO_GRAPH_TYPE;
@@ -1933,3 +1948,18 @@ sheet_objects_init (void)
 	sov_so_quark = g_quark_from_static_string ("SheetObject");
 	sov_container_quark = g_quark_from_static_string ("SheetObjectViewContainer");
 }
+
+/**
+ * sheet_objects_shutdown: (skip)
+ */
+void
+sheet_objects_shutdown (void)
+{
+	if (so_create_view_src != 0) {
+		g_source_remove (so_create_view_src);
+		so_create_view_src = 0;
+	}
+
+	g_ptr_array_free (so_create_view_sos, TRUE);
+	so_create_view_sos = NULL;
+}
