@@ -512,17 +512,13 @@ cb_collect_names (G_GNUC_UNUSED gconstpointer key,
 	*plist = g_slist_prepend (*plist, expr_name_ref (nexpr));
 }
 
-/* Append the sheets of workbook wb2 to workbook wb.  Resize sheets
-   if necessary.  Fix workbook links in sheet if necessary.
-   Merge names in workbook scope (conflicts result in an error). */
 static gboolean
-merge_single (Workbook *wb, Workbook *wb2,
-	      int cmax, int rmax,
-	      GOCmdContext *cc)
+merge_single_names (Workbook *wb, Workbook *wb2, GOCmdContext *cc)
 {
 	/* Move names with workbook scope in wb2 over to wb */
-	GSList *names = g_slist_sort (gnm_named_expr_collection_list (wb2->names),
-				      (GCompareFunc)expr_name_cmp_by_name);
+	GSList *names = g_slist_sort
+		(gnm_named_expr_collection_list (wb2->names),
+		 (GCompareFunc)expr_name_cmp_by_name);
 	GSList *p;
 
 	for (p = names; p; p = p->next) {
@@ -542,7 +538,8 @@ merge_single (Workbook *wb, Workbook *wb2,
 
 		parse_pos_init (&pp, wb, NULL, 0, 0);
 		nexpr2 = expr_name_lookup (&pp, name);
-		if (nexpr2 /* FIXME: && nexpr2-is-not-the-same-as-nexpr */) {
+		 /* FIXME: && nexpr2-is-not-the-same-as-nexpr */
+		if (nexpr2) {
 			g_printerr (_("Name conflict during merge: '%s' appears twice at workbook scope.\n"),
 				    name);
 			g_slist_free (names);
@@ -555,6 +552,22 @@ merge_single (Workbook *wb, Workbook *wb2,
 	}
 	g_slist_free (names);
 
+	return FALSE;
+}
+
+
+// Append the sheets of workbook wb2 to workbook wb.
+// Resize sheets as necessary.
+// Fix workbook links in sheet if necessary.
+// Merge names in workbook scope (conflicts result in an error).
+static gboolean
+merge_single (Workbook *wb, Workbook *wb2,
+	      int cmax, int rmax,
+	      GOCmdContext *cc)
+{
+	if (merge_single_names (wb, wb2, cc))
+		return TRUE;
+
 	while (workbook_sheet_count (wb2) > 0) {
 		/* Remove sheet from incoming workbook */
 		Sheet *sheet = workbook_sheet_by_index (wb2, 0);
@@ -563,6 +576,8 @@ merge_single (Workbook *wb, Workbook *wb2,
 		char *sheet_name;
 		gboolean err;
 		GSList *names = NULL;
+		GSList *objects;
+		GSList *l;
 
 		g_object_ref (sheet);
 		workbook_sheet_delete (sheet);
@@ -595,6 +610,23 @@ merge_single (Workbook *wb, Workbook *wb2,
 		/* Insert and revive the sheet */
 		workbook_sheet_attach_at_pos (wb, sheet, loc);
 		dependents_revive_sheet (sheet);
+
+		// Pull the objects out and put them back in so they
+		// notice the change of workbook.
+		objects = g_slist_copy_deep (sheet->sheet_objects,
+					     (GCopyFunc)g_object_ref,
+					     NULL);
+		for (l = objects; l; l = l->next) {
+			SheetObject *so = l->data;
+			sheet_object_clear_sheet (so);
+		}
+		objects = g_slist_reverse (objects);
+		for (l = objects; l; l = l->next) {
+			SheetObject *so = l->data;
+			sheet_object_set_sheet (so, sheet);
+		}
+		g_slist_free_full (objects, g_object_unref);
+
 		g_object_unref (sheet);
 	}
 
@@ -630,6 +662,9 @@ merge (Workbook *wb, char const *inputs[],
 	}
 
 	g_slist_free_full (wbs, g_object_unref);
+
+	workbook_share_expressions (wb, TRUE);
+
 	return result;
 }
 
@@ -1202,8 +1237,10 @@ convert (char const *inarg, char const *outarg, char const *mergeargs[],
 	}
 
 	if (mergeargs != NULL) {
-		if (merge (wb, mergeargs, fo, io_context, cc))
+		if (merge (wb, mergeargs, fo, io_context, cc)) {
+			res = TRUE;
 			goto out;
+		}
 	}
 
 	if (ssconvert_goal_seek) {
