@@ -1828,8 +1828,9 @@ do_check_date (const char *data, StfGuessFormats flag,
 	       GODateConventions const *date_conv)
 {
 	GnmValue *v;
-	gboolean this_mbd, this_ybm;
+	gboolean has_all, this_mbd, this_ybm;
 	int imbd;
+	GOFormat const *fmt;
 
 	if (!(*possible & flag))
 		return;
@@ -1838,7 +1839,17 @@ do_check_date (const char *data, StfGuessFormats flag,
 	if (!v || !VALUE_FMT (v))
 		goto fail;
 
-	imbd = go_format_month_before_day (VALUE_FMT (v));
+	fmt = VALUE_FMT (v);
+	has_all = (go_format_has_year (fmt) &&
+		   go_format_has_month (fmt) &&
+		   go_format_has_day (fmt));
+	if (!has_all) {
+		// See #401
+		// Avoid detecting 1.9999 is a date.
+		goto fail;
+	}
+
+	imbd = go_format_month_before_day (fmt);
 	this_mbd = (imbd >= 1);
 	this_ybm = (imbd == 2);
 	if (mbd != this_mbd || ybm != this_ybm)
@@ -2014,10 +2025,17 @@ stf_parse_options_guess_formats (StfParseOptions_t *po, char const *data)
 				g_printerr ("col=%d; after [%s] possible=0x%x\n", col, data, possible);
 		}
 
-		if ((possible & STF_GUESS_NUMBER_DEC_EITHER) == STF_GUESS_NUMBER_DEC_EITHER &&
-		    !seen_dot && !seen_comma) {
-			// It doesn't matter what the separators are
-			possible &= ~STF_GUESS_NUMBER_DEC_COMMA;
+		if ((possible & STF_GUESS_NUMBER_DEC_EITHER) == STF_GUESS_NUMBER_DEC_EITHER) {
+			if (!seen_dot && !seen_comma) {
+				// It doesn't matter what the separators are
+				possible &= ~STF_GUESS_NUMBER_DEC_COMMA;
+			} else if (seen_dot && !seen_comma) {
+				// Hope for the best
+				possible &= ~STF_GUESS_NUMBER_DEC_COMMA;
+			} else if (seen_comma && !seen_dot) {
+				// Hope for the best
+				possible &= ~STF_GUESS_NUMBER_DEC_EITHER;
+			}
 		}
 
 		switch (possible) {
