@@ -1,4 +1,3 @@
-/* vim: set sw=8: -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*
  * stf.c : Utilizes the stf-parse engine and the dialog-stf to provide a plug-in for
  *         importing text files with a structure (CSV/fixed width)
@@ -22,34 +21,34 @@
 
 #include <gnumeric-config.h>
 #include <glib/gi18n-lib.h>
-#include "gnumeric.h"
-#include "stf.h"
-#include "stf-export.h"
+#include <gnumeric.h>
+#include <stf.h>
+#include <stf-export.h>
 
 #include <goffice/goffice.h>
-#include "cell.h"
-#include "sheet.h"
-#include "sheet-view.h"
-#include "sheet-style.h"
-#include "style.h"
-#include "mstyle.h"
-#include "command-context.h"
-#include "wbc-gtk.h"
-#include "workbook-view.h"
-#include "workbook.h"
-#include "dialog-stf.h"
-#include "dialog-stf-export.h"
-#include "position.h"
-#include "expr.h"
-#include "value.h"
-#include "gnm-format.h"
-#include "selection.h"
-#include "ranges.h"
-#include "clipboard.h"
-#include "parse-util.h"
-#include "commands.h"
-#include "gui-util.h"
-#include "gutils.h"
+#include <cell.h>
+#include <sheet.h>
+#include <sheet-view.h>
+#include <sheet-style.h>
+#include <style.h>
+#include <mstyle.h>
+#include <command-context.h>
+#include <wbc-gtk.h>
+#include <workbook-view.h>
+#include <workbook.h>
+#include <dialogs/dialog-stf.h>
+#include <dialogs/dialog-stf-export.h>
+#include <position.h>
+#include <expr.h>
+#include <value.h>
+#include <gnm-format.h>
+#include <selection.h>
+#include <ranges.h>
+#include <clipboard.h>
+#include <parse-util.h>
+#include <commands.h>
+#include <gui-util.h>
+#include <gutils.h>
 
 #include <gsf/gsf-input.h>
 #include <string.h>
@@ -58,7 +57,6 @@
 #include <gsf/gsf-utils.h>
 #include <locale.h>
 
-
 static void
 stf_warning (GOIOContext *context, char const *msg)
 {
@@ -360,9 +358,9 @@ clear_stray_NULs (GOIOContext *context, GString *utf8data)
 	if (null_chars > 0) {
 		gchar const *format;
 		gchar *msg;
-		format = ngettext ("The file contains %d NULL character. "
+		format = ngettext ("The file contains %d NUL character. "
 				   "It has been changed to a space.",
-				   "The file contains %d NULL characters. "
+				   "The file contains %d NUL characters. "
 				   "They have been changed to spaces.",
 				   null_chars);
 		msg = g_strdup_printf (format, null_chars);
@@ -486,11 +484,10 @@ stf_read_workbook_auto_csvtab (G_GNUC_UNUSED GOFileOpener const *fo, gchar const
 /***********************************************************************************/
 
 static void
-stf_write_csv (G_GNUC_UNUSED GOFileSaver const *fs, GOIOContext *context,
+stf_write_csv (GOFileSaver const *fs, GOIOContext *context,
 	       GoView const *view, GsfOutput *output)
 {
 	Sheet *sheet;
-	GnmRangeRef const *range;
 	WorkbookView *wbv = GNM_WORKBOOK_VIEW (view);
 
 	GnmStfExport *config = g_object_new
@@ -499,14 +496,9 @@ stf_write_csv (G_GNUC_UNUSED GOFileSaver const *fs, GOIOContext *context,
 		 "quoting-triggers", ", \t\n\"",
 		 NULL);
 
-	/* FIXME: this is crap in both branches of the "if".  */
-	range = g_object_get_data (G_OBJECT (wb_view_get_workbook (wbv)), "ssconvert-range");
-	if (range && range->a.sheet)
-		sheet = range->a.sheet;
-	else
-		sheet = wb_view_cur_sheet (wbv);
-
-	gnm_stf_export_options_sheet_list_add (config, sheet);
+	sheet = gnm_file_saver_get_sheet (fs, wbv);
+	if (sheet)
+		gnm_stf_export_options_sheet_list_add (config, sheet);
 
 	if (gnm_stf_export (config) == FALSE)
 		go_cmd_context_error_import (GO_CMD_CONTEXT (context),
@@ -580,6 +572,9 @@ csv_tsv_probe (GOFileOpener const *fo, GsfInput *input, GOFileProbeLevel pl)
 	}
 }
 
+/**
+ * stf_init: (skip)
+ */
 void
 stf_init (void)
 {
@@ -633,10 +628,14 @@ stf_init (void)
 		_("Comma separated values (CSV)"),
 		GO_FILE_FL_MANUAL_REMEMBER, stf_write_csv);
 	go_file_saver_set_save_scope (saver, GO_FILE_SAVE_SHEET);
+	g_object_set (G_OBJECT (saver), "sheet-selection", TRUE, NULL);
 	go_file_saver_register (saver);
 	g_object_unref (saver);
 }
 
+/**
+ * stf_shutdown: (skip)
+ */
 void
 stf_shutdown (void)
 {
