@@ -107,7 +107,7 @@ gnm_style_cond_is_valid (GnmStyleCond const *cond)
 	N = gnm_style_cond_op_operands (cond->op);
 	for (ui = 0; ui < G_N_ELEMENTS (cond->deps); ui++) {
 		gboolean need = (ui < N);
-		gboolean have = (cond->deps[ui].texpr != NULL);
+		gboolean have = (dependent_managed_get_expr (&cond->deps[ui]) != NULL);
 		if (have != need)
 			return FALSE;
 	}
@@ -131,27 +131,42 @@ gnm_style_cond_new (GnmStyleCondOp op, Sheet *sheet)
 }
 
 /**
- * gnm_style_cond_dup:
+ * gnm_style_cond_dup_to:
  * @src: #GnmStyleCond
+ * @sheet: Sheet that the duplicate should live on
  *
  * Returns: (transfer full): the newly allocated #GnmStyleCond.
  **/
-GnmStyleCond *
-gnm_style_cond_dup (GnmStyleCond const *src)
+static GnmStyleCond *
+gnm_style_cond_dup_to (GnmStyleCond const *src, Sheet *sheet)
 {
 	GnmStyleCond *dst;
 	unsigned ui;
 
 	g_return_val_if_fail (src != NULL, NULL);
 
-	dst = gnm_style_cond_new (src->op, gnm_style_cond_get_sheet (src));
+	dst = gnm_style_cond_new (src->op, sheet);
 	gnm_style_cond_set_overlay (dst, src->overlay);
 	for (ui = 0; ui < 2; ui++)
-		gnm_style_cond_set_expr (dst, src->deps[ui].texpr, ui);
+		gnm_style_cond_set_expr (dst, dependent_managed_get_expr (&src->deps[ui]), ui);
 
 	return dst;
 }
 
+/**
+ * gnm_style_cond_dup:
+ * @src: #GnmStyleCond
+ *
+ * Returns: (transfer full): the newly allocated #GnmStyleCond.
+ **/
+static GnmStyleCond *
+gnm_style_cond_dup (GnmStyleCond const *src)
+{
+	g_return_val_if_fail (src != NULL, NULL);
+
+	return gnm_style_cond_dup_to (src, gnm_style_cond_get_sheet (src));
+}
+
 void
 gnm_style_cond_free (GnmStyleCond *cond)
 {
@@ -191,19 +206,7 @@ Sheet *
 gnm_style_cond_get_sheet (GnmStyleCond const *cond)
 {
 	g_return_val_if_fail (cond != NULL, NULL);
-	return cond->deps[0].sheet;
-}
-
-void
-gnm_style_cond_set_sheet (GnmStyleCond *cond, Sheet *sheet)
-{
-	int ui;
-
-	g_return_if_fail (cond != NULL);
-	g_return_if_fail (IS_SHEET (sheet));
-
-	for (ui = 0; ui < 2; ui++)
-		dependent_managed_set_sheet (&cond->deps[ui], sheet);
+	return cond->deps[0].base.sheet;
 }
 
 /**
@@ -219,7 +222,7 @@ gnm_style_cond_get_expr (GnmStyleCond const *cond, unsigned idx)
 	g_return_val_if_fail (cond != NULL, NULL);
 	g_return_val_if_fail (idx < G_N_ELEMENTS (cond->deps), NULL);
 
-	return cond->deps[idx].texpr;
+	return dependent_managed_get_expr (&cond->deps[idx]);
 }
 
 void
@@ -566,11 +569,11 @@ gnm_style_cond_eval (GnmStyleCond const *cond, GnmValue const *cv,
 
 	switch (gnm_style_cond_op_operands (cond->op)) {
 	case 2:
-		val1 = gnm_expr_top_eval (cond->deps[1].texpr, ep,
+		val1 = gnm_expr_top_eval (cond->deps[1].base.texpr, ep,
 					  GNM_EXPR_EVAL_SCALAR_NON_EMPTY);
 		/* Fall through */
 	case 1:
-		val0 = gnm_expr_top_eval (cond->deps[0].texpr, ep,
+		val0 = gnm_expr_top_eval (cond->deps[0].base.texpr, ep,
 					  GNM_EXPR_EVAL_SCALAR_NON_EMPTY);
 		/* Fall through */
 	case 0:
@@ -674,10 +677,10 @@ gnm_style_cond_equal (GnmStyleCond const *ca, GnmStyleCond const *cb,
 
 	N = gnm_style_cond_op_operands (ca->op);
 	for (oi = 0; oi < N; oi++) {
-		if (!relax_sheet && ca->deps[oi].sheet != cb->deps[oi].sheet)
+		if (!relax_sheet && ca->deps[oi].base.sheet != cb->deps[oi].base.sheet)
 			return FALSE;
-		if (!gnm_expr_top_equal (ca->deps[oi].texpr,
-					 cb->deps[oi].texpr))
+		if (!gnm_expr_top_equal (ca->deps[oi].base.texpr,
+					 cb->deps[oi].base.texpr))
 			return FALSE;
 	}
 
@@ -731,6 +734,36 @@ gnm_style_conditions_new (Sheet *sheet)
 	return res;
 }
 
+/**
+ * gnm_style_conditions_dup_to:
+ * @sc: (nullable): the #GnmStyleConditions to duplicate.
+ * @sheet: Sheet that the duplicate should live on
+ *
+ * Returns: (transfer full) (nullable): the duplicated #GnmStyleConditions.
+ **/
+GnmStyleConditions *
+gnm_style_conditions_dup_to (GnmStyleConditions const *sc, Sheet *sheet)
+{
+	GnmStyleConditions *dup;
+	GPtrArray const *ga;
+	if (sc == NULL)
+		return NULL;
+
+	dup = gnm_style_conditions_new (sheet);
+	ga = gnm_style_conditions_details (sc);
+	if (ga != NULL) {
+		guint i;
+		GPtrArray *ga_dup = g_ptr_array_sized_new (ga->len);
+		for (i = 0; i < ga->len; i++) {
+			GnmStyleCond *cond = g_ptr_array_index (ga, i);
+			g_ptr_array_add (ga_dup, gnm_style_cond_dup_to (cond, sheet));
+		}
+		dup->conditions = ga_dup;
+	}
+	return dup;
+}
+
+
 /**
  * gnm_style_conditions_dup:
  * @sc: (nullable): the #GnmStyleConditions to duplicate.
@@ -740,23 +773,9 @@ gnm_style_conditions_new (Sheet *sheet)
 GnmStyleConditions *
 gnm_style_conditions_dup (GnmStyleConditions const *sc)
 {
-	GnmStyleConditions *dup;
-	GPtrArray const *ga;
-	if (sc == NULL)
-		return NULL;
-
-	dup = gnm_style_conditions_new (gnm_style_conditions_get_sheet (sc));
-	ga = gnm_style_conditions_details (sc);
-	if (ga != NULL) {
-		guint i;
-		GPtrArray *ga_dup = g_ptr_array_sized_new (ga->len);
-		for (i = 0; i < ga->len; i++) {
-			GnmStyleCond *cond = g_ptr_array_index (ga, i);
-			g_ptr_array_add (ga_dup, gnm_style_cond_dup (cond));
-		}
-		dup->conditions = ga_dup;
-	}
-	return dup;
+	return sc
+		? gnm_style_conditions_dup_to (sc, gnm_style_conditions_get_sheet (sc))
+		: NULL;
 }
 
 #define MIX(H) do {				\
@@ -846,24 +865,6 @@ gnm_style_conditions_get_sheet (GnmStyleConditions const *sc)
 	return sc->sheet;
 }
 
-void
-gnm_style_conditions_set_sheet (GnmStyleConditions *sc, Sheet *sheet)
-{
-	GPtrArray const *ga;
-	unsigned ui;
-
-	g_return_if_fail (sc != NULL);
-	g_return_if_fail (IS_SHEET (sheet));
-
-	sc->sheet = sheet;
-	ga = gnm_style_conditions_details (sc);
-	for (ui = 0; ga && ui < ga->len; ui++) {
-		GnmStyleCond *cond = g_ptr_array_index (ga, ui);
-		gnm_style_cond_set_sheet (cond, sheet);
-	}
-}
-
-
 /**
  * gnm_style_conditions_details:
  * @sc: #GnmStyleConditions
