@@ -1,5 +1,4 @@
-/* vim: set sw=8: -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
-/**
+/*
  * gnm-format-sel.c: Gnumeric extensions to the format selector widget
  *
  * This program is free software; you can redistribute it and/or modify
@@ -13,15 +12,14 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ * along with this program; if not, see <https://www.gnu.org/licenses/>.
  **/
 
 #include <gnumeric-config.h>
-#include "gnm-format-sel.h"
-#include "src/value.h"
-#include "src/gnm-format.h"
-#include "src/style-font.h"
+#include <widgets/gnm-format-sel.h>
+#include <src/value.h>
+#include <src/gnm-format.h>
+#include <src/style-font.h>
 
 static char *
 cb_generate_preview (GOFormatSel *gfs, PangoAttrList **attrs)
@@ -55,6 +53,11 @@ cb_generate_preview (GOFormatSel *gfs, PangoAttrList **attrs)
 	}
 }
 
+/**
+ * gnm_format_sel_new:
+ *
+ * Returns: (transfer full): a new format selector
+ */
 GtkWidget *
 gnm_format_sel_new (void)
 {
