@@ -1,4 +1,3 @@
-/* vim: set sw=8: -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 
 /*
  * workbook-control.c: The base class for the displaying a workbook.
@@ -22,23 +21,23 @@
  */
 
 #include <gnumeric-config.h>
-#include "gnm-i18n.h"
-#include "gnumeric.h"
-#include "workbook-control-priv.h"
+#include <gnm-i18n.h>
+#include <gnumeric.h>
+#include <workbook-control-priv.h>
 
-#include "application.h"
-#include "workbook-view.h"
-#include "workbook-priv.h"
-#include "sheet.h"
-#include "sheet-view.h"
-#include "sheet-utils.h"
-#include "selection.h"
-#include "commands.h"
-#include "value.h"
-#include "ranges.h"
-#include "expr-name.h"
-#include "expr.h"
-#include "command-context.h"
+#include <application.h>
+#include <workbook-view.h>
+#include <workbook-priv.h>
+#include <sheet.h>
+#include <sheet-view.h>
+#include <sheet-utils.h>
+#include <selection.h>
+#include <commands.h>
+#include <value.h>
+#include <ranges.h>
+#include <expr-name.h>
+#include <expr.h>
+#include <command-context.h>
 #include <goffice/goffice.h>
 #include <gsf/gsf-impl-utils.h>
 
