@@ -55,7 +55,8 @@
 
 enum {
 	PROP_0,
-	PROP_RECALC_MODE
+	PROP_RECALC_MODE,
+	PROP_BEING_LOADED
 };
 enum {
 	SHEET_ORDER_CHANGED,
@@ -224,6 +225,7 @@ workbook_init (GObject *object)
 	wb->is_placeholder = FALSE;
 	wb->wb_views = NULL;
 	wb->sheets = g_ptr_array_new ();
+	wb->sheet_size_cached = FALSE;
 	wb->sheet_hash_private = g_hash_table_new (g_str_hash, g_str_equal);
 	wb->sheet_order_dependents = NULL;
 	wb->sheet_local_functions = NULL;
@@ -249,6 +251,7 @@ workbook_init (GObject *object)
 	wb->during_destruction = FALSE;
 	wb->being_reordered    = FALSE;
 	wb->recursive_dirty_enabled = TRUE;
+	wb->being_loaded = FALSE;
 
 	gnm_app_workbook_list_add (wb);
 }
@@ -263,6 +266,9 @@ workbook_get_property (GObject *object, guint property_id,
 	case PROP_RECALC_MODE:
 		g_value_set_boolean (value, wb->recalc_auto);
 		break;
+	case PROP_BEING_LOADED:
+		g_value_set_boolean (value, wb->being_loaded);
+		break;
 	default:
 		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
 		break;
@@ -279,6 +285,9 @@ workbook_set_property (GObject *object, guint property_id,
 	case PROP_RECALC_MODE:
 		workbook_set_recalcmode (wb, g_value_get_boolean (value));
 		break;
+	case PROP_BEING_LOADED:
+		wb->being_loaded = g_value_get_boolean (value);
+		break;
 	default:
 		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
 		break;
@@ -349,6 +358,14 @@ workbook_class_init (GObjectClass *gobject_class)
 				       GSF_PARAM_STATIC |
 				       G_PARAM_READWRITE));
 
+        g_object_class_install_property (gobject_class, PROP_BEING_LOADED,
+		 g_param_spec_boolean ("being-loaded",
+				       P_("Being loaded"),
+				       P_("Workbook is currently being loaded."),
+				       TRUE,
+				       GSF_PARAM_STATIC |
+				       G_PARAM_READWRITE));
+
 	signals[SHEET_ORDER_CHANGED] = g_signal_new ("sheet_order_changed",
 		GNM_WORKBOOK_TYPE,
 		G_SIGNAL_RUN_LAST,
@@ -673,7 +690,7 @@ workbook_share_expressions (Workbook *wb, gboolean freeit)
 	}
 
 	if (freeit) {
-		gnm_expr_sharer_destroy (es);
+		gnm_expr_sharer_unref (es);
 		es = NULL;
 	}
 
@@ -1013,6 +1030,7 @@ workbook_sheet_attach_at_pos (Workbook *wb, Sheet *new_sheet, int pos)
 	g_hash_table_insert (wb->sheet_hash_private,
 			     new_sheet->name_case_insensitive,
 			     new_sheet);
+	wb->sheet_size_cached = FALSE;
 
 	WORKBOOK_FOREACH_VIEW (wb, view,
 		wb_view_sheet_add (view, new_sheet););
@@ -1135,6 +1153,7 @@ workbook_sheet_delete (Sheet *sheet)
 	/* All is fine, remove the sheet */
 	pre_sheet_index_change (wb);
 	g_ptr_array_remove_index (wb->sheets, sheet_index);
+	wb->sheet_size_cached = FALSE;
 	workbook_sheet_index_update (wb, sheet_index);
 	sheet->index_in_wb = -1;
 	g_hash_table_remove (wb->sheet_hash_private, sheet->name_case_insensitive);
@@ -1301,7 +1320,7 @@ workbook_sheet_rename (Workbook *wb,
  * @is_undo: undo vs redo
  * @cmd: command
  *
- * Returns: the 1 based index of the @key command, or 0 if it is not found
+ * Returns: the 1 based index of the @cmd command, or 0 if it is not found
  * (which would be a programmer error).
  **/
 unsigned
@@ -1393,22 +1412,40 @@ workbook_set_1904 (Workbook *wb, gboolean base1904)
 
 /**
  * workbook_get_sheet_size:
- * @wb: #Workbook
+ * @wb: (nullable): #Workbook
  *
- * Returns: (transfer none): the current sheet size for @wb.
+ * Returns: (transfer none): the current sheet size for @wb.  If sheets are
+ * not of uniform size, this will be some size that is big enough in both
+ * directions for all sheets.  That size isn't necessarily one that could
+ * be used to create a new sheet.
  **/
 GnmSheetSize const *
 workbook_get_sheet_size (Workbook const *wb)
 {
-	if (wb == NULL || workbook_sheet_count (wb) == 0) {
-		static const GnmSheetSize max_size = {
-			GNM_MAX_COLS, GNM_MAX_ROWS
-		};
+	static const GnmSheetSize max_size = {
+		GNM_MAX_COLS, GNM_MAX_ROWS
+	};
+	int n = wb ? workbook_sheet_count (wb) : 0;
 
+	if (n == 0)
 		return &max_size;
+
+	if (!wb->sheet_size_cached) {
+		Workbook *wb1 = (Workbook *)wb;
+		int i;
+
+		wb1->sheet_size = *gnm_sheet_get_size (workbook_sheet_by_index (wb, 0));
+		for (i = 1; i < n; i++) {
+			Sheet *sheet = workbook_sheet_by_index (wb, i);
+			GnmSheetSize const *ss = gnm_sheet_get_size (sheet);
+			wb1->sheet_size.max_cols = MAX (wb->sheet_size.max_cols, ss->max_cols);
+			wb1->sheet_size.max_rows = MAX (wb->sheet_size.max_rows, ss->max_rows);
+		}
+
+		wb1->sheet_size_cached = TRUE;
 	}
 
-	return gnm_sheet_get_size (workbook_sheet_by_index (wb, 0));
+	return &wb->sheet_size;
 }
 
 /* ------------------------------------------------------------------------- */
@@ -1445,7 +1482,7 @@ workbook_sheet_state_new (const Workbook *wb)
 }
 
 void
-workbook_sheet_state_free (WorkbookSheetState *wss)
+workbook_sheet_state_unref (WorkbookSheetState *wss)
 {
 	int i;
 
@@ -1478,7 +1515,7 @@ workbook_sheet_state_get_type (void)
 	if (t == 0) {
 		t = g_boxed_type_register_static ("WorkbookSheetState",
 			 (GBoxedCopyFunc)workbook_sheet_state_ref,
-			 (GBoxedFreeFunc)workbook_sheet_state_free);
+			 (GBoxedFreeFunc)workbook_sheet_state_unref);
 	}
 	return t;
 }
