@@ -7,25 +7,7 @@ from gi.repository import Gnm
 from gi.repository import GOffice as Go
 Gnm.init()
 
-import os.path
-
-def atomize_path(p):
-    res=[]
-    while 1:
-        h,t = os.path.split(p)
-        if t != "":
-            res.append(t)
-        if h == "":
-            break
-        if h == p:
-            res.append(h)
-            break
-        p = h
-    res.reverse()
-    return res
-
-l=atomize_path(os.path.dirname(gi.overrides.Gnm.__file__))
-if len(l) > 3 and l[-3] == "introspection":
+if Gnm.in_tree:
     print("Using in-tree gi.overrides.Gnm")
 else:
     print("Using installed gi.overrides.Gnm at {}"
